print("import: 'CoreServices'")
import CoreServices

print("import: 'CoreServices.CarbonCore'")
import CoreServices.CarbonCore

print("import: 'CoreServices.DictionaryServices'")
import CoreServices.DictionaryServices

print("import: 'CoreServices.LaunchServices'")
import CoreServices.LaunchServices

print("import: 'CoreServices.Metadata'")
import CoreServices.Metadata

print("import: 'CoreServices.SearchKit'")
import CoreServices.SearchKit




# This file is generated by objective.metadata
#
# Last update: Sun Feb 20 18:46:06 2022
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
misc.update(
    {
        "LSItemInfoRecord": objc.createStructType(
            "CoreServices.LaunchServices.LSItemInfoRecord",
            b"{LSItemInfoRecord=III^{__CFString=}}",
            ["flags", "filetype", "creator", "extension"],
            None,
            2,
        ),
        "LSLaunchFSRefSpec": objc.createStructType(
            "CoreServices.LaunchServices.LSLaunchFSRefSpec",
            b"{LSLaunchFSRefSpec=^{FSRef=[80C]}Q^{FSRef=[80C]}^{AEDesc=I^^{OpaqueAEDataStorageType=}}I^v}",
            [
                "appRef",
                "numDocs",
                "itemRefs",
                "passThruParams",
                "launchFlags",
                "asyncRefCon",
            ],
            None,
            2,
        ),
        "LSApplicationParameters": objc.createStructType(
            "CoreServices.LaunchServices.LSApplicationParameters",
            b"{LSApplicationParameters=qI^{FSRef=[80C]}^v^{__CFDictionary=}^{__CFArray=}^{AEDesc=I^^{OpaqueAEDataStorageType=}}}",
            [
                "version",
                "flags",
                "application",
                "asyncLaunchRefCon",
                "environment",
                "argv",
                "initialEvent",
            ],
        ),
        "LSLaunchURLSpec": objc.createStructType(
            "CoreServices.LaunchServices.LSLaunchURLSpec",
            b"{LSLaunchURLSpec=^{__CFURL=}^{__CFArray=}^{AEDesc=I^^{OpaqueAEDataStorageType=}}I^v}",
            ["appURL", "itemURLs", "passThruParams", "launchFlags", "asyncRefCon"],
            None,
            2,
        ),
    }
)
constants = """$kLSItemContentType$kLSItemDisplayKind$kLSItemDisplayName$kLSItemExtension$kLSItemExtensionIsHidden$kLSItemFileCreator$kLSItemFileType$kLSItemIsInvisible$kLSItemQuarantineProperties$kLSItemRoleHandlerDisplayName$kLSQuarantineAgentBundleIdentifierKey$kLSQuarantineAgentNameKey$kLSQuarantineDataURLKey$kLSQuarantineOriginURLKey$kLSQuarantineTimeStampKey$kLSQuarantineTypeCalendarEventAttachment$kLSQuarantineTypeEmailAttachment$kLSQuarantineTypeInstantMessageAttachment$kLSQuarantineTypeKey$kLSQuarantineTypeOtherAttachment$kLSQuarantineTypeOtherDownload$kLSQuarantineTypeWebDownload$kLSSharedFileListFavoriteItems$kLSSharedFileListFavoriteVolumes$kLSSharedFileListGlobalLoginItems$kLSSharedFileListItemBeforeFirst@==^{OpaqueLSSharedFileListItemRef=}$kLSSharedFileListItemHidden$kLSSharedFileListItemLast@==^{OpaqueLSSharedFileListItemRef=}$kLSSharedFileListLoginItemHidden$kLSSharedFileListRecentApplicationItems$kLSSharedFileListRecentDocumentItems$kLSSharedFileListRecentItemsMaxAmount$kLSSharedFileListRecentServerItems$kLSSharedFileListSessionLoginItems$kLSSharedFileListVolumesComputerVisible$kLSSharedFileListVolumesIDiskVisible$kLSSharedFileListVolumesNetworkVisible$kUTExportedTypeDeclarationsKey$kUTImportedTypeDeclarationsKey$kUTTagClassFilenameExtension$kUTTagClassMIMEType$kUTTagClassNSPboardType$kUTTagClassOSType$kUTType3DContent$kUTTypeAVIMovie$kUTTypeAliasFile$kUTTypeAliasRecord$kUTTypeAppleICNS$kUTTypeAppleProtectedMPEG4Audio$kUTTypeAppleProtectedMPEG4Video$kUTTypeAppleScript$kUTTypeApplication$kUTTypeApplicationBundle$kUTTypeApplicationFile$kUTTypeArchive$kUTTypeAssemblyLanguageSource$kUTTypeAudio$kUTTypeAudioInterchangeFileFormat$kUTTypeAudiovisualContent$kUTTypeBMP$kUTTypeBinaryPropertyList$kUTTypeBookmark$kUTTypeBundle$kUTTypeBzip2Archive$kUTTypeCHeader$kUTTypeCPlusPlusHeader$kUTTypeCPlusPlusSource$kUTTypeCSource$kUTTypeCalendarEvent$kUTTypeCommaSeparatedText$kUTTypeCompositeContent$kUTTypeConformsToKey$kUTTypeContact$kUTTypeContent$kUTTypeData$kUTTypeDatabase$kUTTypeDelimitedText$kUTTypeDescriptionKey$kUTTypeDirectory$kUTTypeDiskImage$kUTTypeElectronicPublication$kUTTypeEmailMessage$kUTTypeExecutable$kUTTypeFileURL$kUTTypeFlatRTFD$kUTTypeFolder$kUTTypeFont$kUTTypeFramework$kUTTypeGIF$kUTTypeGNUZipArchive$kUTTypeHTML$kUTTypeICO$kUTTypeIconFileKey$kUTTypeIdentifierKey$kUTTypeImage$kUTTypeInkText$kUTTypeInternetLocation$kUTTypeItem$kUTTypeJPEG$kUTTypeJPEG2000$kUTTypeJSON$kUTTypeJavaArchive$kUTTypeJavaClass$kUTTypeJavaScript$kUTTypeJavaSource$kUTTypeLivePhoto$kUTTypeLog$kUTTypeM3UPlaylist$kUTTypeMIDIAudio$kUTTypeMP3$kUTTypeMPEG$kUTTypeMPEG2TransportStream$kUTTypeMPEG2Video$kUTTypeMPEG4$kUTTypeMPEG4Audio$kUTTypeMessage$kUTTypeMountPoint$kUTTypeMovie$kUTTypeOSAScript$kUTTypeOSAScriptBundle$kUTTypeObjectiveCPlusPlusSource$kUTTypeObjectiveCSource$kUTTypePDF$kUTTypePHPScript$kUTTypePICT$kUTTypePKCS12$kUTTypePNG$kUTTypePackage$kUTTypePerlScript$kUTTypePlainText$kUTTypePlaylist$kUTTypePluginBundle$kUTTypePresentation$kUTTypePropertyList$kUTTypePythonScript$kUTTypeQuickLookGenerator$kUTTypeQuickTimeImage$kUTTypeQuickTimeMovie$kUTTypeRTF$kUTTypeRTFD$kUTTypeRawImage$kUTTypeReferenceURLKey$kUTTypeResolvable$kUTTypeRubyScript$kUTTypeScalableVectorGraphics$kUTTypeScript$kUTTypeShellScript$kUTTypeSourceCode$kUTTypeSpotlightImporter$kUTTypeSpreadsheet$kUTTypeSwiftSource$kUTTypeSymLink$kUTTypeSystemPreferencesPane$kUTTypeTIFF$kUTTypeTXNTextAndMultimediaData$kUTTypeTabSeparatedText$kUTTypeTagSpecificationKey$kUTTypeText$kUTTypeToDoItem$kUTTypeURL$kUTTypeURLBookmarkData$kUTTypeUTF16ExternalPlainText$kUTTypeUTF16PlainText$kUTTypeUTF8PlainText$kUTTypeUTF8TabSeparatedText$kUTTypeUnixExecutable$kUTTypeVCard$kUTTypeVersionKey$kUTTypeVideo$kUTTypeVolume$kUTTypeWaveformAudio$kUTTypeWebArchive$kUTTypeWindowsExecutable$kUTTypeX509Certificate$kUTTypeXML$kUTTypeXMLPropertyList$kUTTypeXPCService$kUTTypeZipArchive$"""
enums = """$appleMenuFolderIconResource@-3982$controlPanelFolderIconResource@-3976$desktopIconResource@-3992$dropFolderIconResource@-3979$extensionsFolderIconResource@-3973$floppyIconResource@-3998$fontsFolderIconResource@-3968$fullTrashIconResource@-3984$genericApplicationIconResource@-3996$genericCDROMIconResource@-3987$genericDeskAccessoryIconResource@-3991$genericDocumentIconResource@-4000$genericEditionFileIconResource@-3989$genericExtensionIconResource@-16415$genericFileServerIconResource@-3972$genericFolderIconResource@-3999$genericHardDiskIconResource@-3995$genericMoverObjectIconResource@-3969$genericPreferencesIconResource@-3971$genericQueryDocumentIconResource@-16506$genericRAMDiskIconResource@-3988$genericStationeryIconResource@-3985$genericSuitcaseIconResource@-3970$kAFPServerIcon@1634103411$kAlertCautionBadgeIcon@1667392615$kAlertCautionIcon@1667331444$kAlertNoteIcon@1852798053$kAlertStopIcon@1937010544$kAliasBadgeIcon@1633838183$kAppearanceFolderIcon@1634758770$kAppleExtrasFolderIcon@1634040004$kAppleLogoIcon@1667330156$kAppleMenuFolderIcon@1634561653$kAppleMenuFolderIconResource@-3982$kAppleMenuIcon@1935765612$kAppleScriptBadgeIcon@1935897200$kAppleTalkIcon@1635019883$kAppleTalkZoneIcon@1635023470$kApplicationSupportFolderIcon@1634956656$kApplicationsFolderIcon@1634758771$kAssistantsFolderIcon@1634956484$kBackwardArrowIcon@1650553455$kBurningIcon@1651864174$kClipboardIcon@1129072976$kClippingPictureTypeIcon@1668051056$kClippingSoundTypeIcon@1668051059$kClippingTextTypeIcon@1668051060$kClippingUnknownTypeIcon@1668051061$kColorSyncFolderIcon@1886547814$kComputerIcon@1919905652$kConnectToIcon@1668178804$kContextualMenuItemsFolderIcon@1668116085$kControlPanelDisabledFolderIcon@1668575812$kControlPanelFolderIcon@1668575852$kControlPanelFolderIconResource@-3976$kControlStripModulesFolderIcon@1935963844$kDeleteAliasIcon@1684106345$kDesktopIcon@1684370283$kDesktopIconResource@-3992$kDocumentsFolderIcon@1685021555$kDropFolderIcon@1684172664$kDropFolderIconResource@-3979$kEjectMediaIcon@1701471587$kExtensionsDisabledFolderIcon@1702392900$kExtensionsFolderIcon@1702392942$kExtensionsFolderIconResource@-3973$kFTPServerIcon@1718906995$kFavoriteItemsIcon@1717663346$kFavoritesFolderIcon@1717663347$kFinderIcon@1179534418$kFloppyIconResource@-3998$kFontSuitcaseIcon@1179011404$kFontsFolderIcon@1718578804$kFontsFolderIconResource@-3968$kForwardArrowIcon@1717662319$kFullTrashIcon@1718907496$kFullTrashIconResource@-3984$kGenericApplicationIcon@1095782476$kGenericApplicationIconResource@-3996$kGenericCDROMIcon@1667523698$kGenericCDROMIconResource@-3987$kGenericComponentIcon@1953001063$kGenericControlPanelIcon@1095782467$kGenericControlStripModuleIcon@1935959414$kGenericDeskAccessoryIcon@1095782468$kGenericDeskAccessoryIconResource@-3991$kGenericDocumentIcon@1685021557$kGenericDocumentIconResource@-4000$kGenericEditionFileIcon@1701082214$kGenericEditionFileIconResource@-3989$kGenericExtensionIcon@1229867348$kGenericExtensionIconResource@-16415$kGenericFileServerIcon@1936881266$kGenericFileServerIconResource@-3972$kGenericFloppyIcon@1718382713$kGenericFolderIcon@1718379634$kGenericFolderIconResource@-3999$kGenericFontIcon@1717987692$kGenericFontScalerIcon@1935895666$kGenericHardDiskIcon@1751413611$kGenericHardDiskIconResource@-3995$kGenericIDiskIcon@1768190827$kGenericMoverObjectIcon@1836021362$kGenericMoverObjectIconResource@-3969$kGenericNetworkIcon@1735288180$kGenericPCCardIcon@1885564259$kGenericPreferencesIcon@1886545254$kGenericPreferencesIconResource@-3971$kGenericQueryDocumentIcon@1902473849$kGenericQueryDocumentIconResource@-16506$kGenericRAMDiskIcon@1918987620$kGenericRAMDiskIconResource@-3988$kGenericRemovableMediaIcon@1919774582$kGenericSharedLibaryIcon@1936223330$kGenericStationeryIcon@1935961955$kGenericStationeryIconResource@-3985$kGenericSuitcaseIcon@1937074548$kGenericSuitcaseIconResource@-3970$kGenericURLIcon@1735750252$kGenericWORMIcon@2003792493$kGenericWindowIcon@1735879022$kGridIcon@1735551332$kGroupIcon@1735554416$kGuestUserIcon@1735750514$kHTTPServerIcon@1752461427$kHelpFolderIcon@-999789456$kHelpIcon@1751477360$kHelpIconResource@-20271$kIPFileServerIcon@1769173622$kIconServicesCatalogInfoMask@531550$kIconServicesNoBadgeFlag@1$kIconServicesNormalUsageFlag@0$kIconServicesUpdateIfNeededFlag@2$kInternationResourcesIcon@1768319340$kInternationalResourcesIcon@1768319340$kInternetFolderIcon@1768846532$kInternetLocationAppleShareIcon@1768710502$kInternetLocationAppleTalkZoneIcon@1768710516$kInternetLocationFTPIcon@1768711796$kInternetLocationFileIcon@1768711785$kInternetLocationGenericIcon@1768712037$kInternetLocationHTTPIcon@1768712308$kInternetLocationMailIcon@1768713569$kInternetLocationNSLNeighborhoodIcon@1768713843$kInternetLocationNewsIcon@1768713847$kInternetPlugInFolderIcon@-999398028$kInternetSearchSitesFolderIcon@1769173862$kKeepArrangedIcon@1634889319$kKeyboardLayoutIcon@1801873772$kLSAcceptAllowLoginUI@2$kLSAcceptDefault@1$kLSAppDoesNotClaimTypeErr@-10820$kLSAppDoesNotSupportSchemeWarning@-10821$kLSAppInTrashErr@-10660$kLSApplicationNotFoundErr@-10814$kLSAttributeNotFoundErr@-10662$kLSAttributeNotSettableErr@-10663$kLSCannotSetInfoErr@-10823$kLSDataErr@-10817$kLSDataTooOldErr@-10816$kLSDataUnavailableErr@-10813$kLSExecutableIncorrectFormat@-10661$kLSGarbageCollectionUnsupportedErr@-10666$kLSHandlerOptionsDefault@0$kLSHandlerOptionsIgnoreCreator@1$kLSIncompatibleApplicationVersionErr@-10664$kLSIncompatibleSystemVersionErr@-10825$kLSInitializeDefaults@1$kLSItemInfoAppIsScriptable@2048$kLSItemInfoAppPrefersClassic@1024$kLSItemInfoAppPrefersNative@512$kLSItemInfoExtensionIsHidden@1048576$kLSItemInfoIsAliasFile@16$kLSItemInfoIsApplication@4$kLSItemInfoIsClassicApp@256$kLSItemInfoIsContainer@8$kLSItemInfoIsInvisible@64$kLSItemInfoIsNativeApp@128$kLSItemInfoIsPackage@2$kLSItemInfoIsPlainFile@1$kLSItemInfoIsSymlink@32$kLSItemInfoIsVolume@4096$kLSLaunchAndDisplayErrors@64$kLSLaunchAndHide@1048576$kLSLaunchAndHideOthers@2097152$kLSLaunchAndPrint@2$kLSLaunchAsync@65536$kLSLaunchDefaults@1$kLSLaunchDontAddToRecents@256$kLSLaunchDontSwitch@512$kLSLaunchHasUntrustedContents@4194304$kLSLaunchInClassic@262144$kLSLaunchInProgressErr@-10818$kLSLaunchInhibitBGOnly@128$kLSLaunchNewInstance@524288$kLSLaunchNoParams@2048$kLSLaunchReserved2@4$kLSLaunchReserved3@8$kLSLaunchReserved4@16$kLSLaunchReserved5@32$kLSLaunchStartClassic@131072$kLSMinCatInfoBitmap@6154$kLSMultipleSessionsNotSupportedErr@-10829$kLSNo32BitEnvironmentErr@-10386$kLSNoClassicEnvironmentErr@-10828$kLSNoExecutableErr@-10827$kLSNoLaunchPermissionErr@-10826$kLSNoRegistrationInfoErr@-10824$kLSNoRosettaEnvironmentErr@-10665$kLSNotAnApplicationErr@-10811$kLSNotInitializedErr@-10812$kLSNotRegisteredErr@-10819$kLSRequestAllFlags@16$kLSRequestAllInfo@4294967295$kLSRequestAppTypeFlags@8$kLSRequestBasicFlagsOnly@4$kLSRequestExtension@1$kLSRequestExtensionFlagsOnly@64$kLSRequestIconAndKind@32$kLSRequestTypeCreator@2$kLSRolesAll@4294967295$kLSRolesEditor@4$kLSRolesNone@1$kLSRolesShell@8$kLSRolesViewer@2$kLSServerCommunicationErr@-10822$kLSSharedFileListDoNotMountVolumes@2$kLSSharedFileListNoUserInteraction@1$kLSUnknownCreator@0$kLSUnknownErr@-10810$kLSUnknownKindID@0$kLSUnknownType@0$kLSUnknownTypeErr@-10815$kLocalesFolderIcon@-999526557$kLockedBadgeIcon@1818387559$kLockedIcon@1819239275$kMacOSReadMeFolderIcon@1836020420$kMountedBadgeIcon@1835164775$kMountedFolderIcon@1835955300$kMountedFolderIconResource@-3977$kNoFilesIcon@1852205420$kNoFolderIcon@1852206180$kNoWriteIcon@1853321844$kOpenFolderIcon@1868983396$kOpenFolderIconResource@-3997$kOwnedFolderIcon@1870098020$kOwnedFolderIconResource@-3980$kOwnerIcon@1937077106$kPreferencesFolderIcon@1886545604$kPreferencesFolderIconResource@-3974$kPrintMonitorFolderIcon@1886547572$kPrintMonitorFolderIconResource@-3975$kPrinterDescriptionFolderIcon@1886413926$kPrinterDriverFolderIcon@-999263644$kPrivateFolderIcon@1886549606$kPrivateFolderIconResource@-3994$kProtectedApplicationFolderIcon@1885433968$kProtectedSystemFolderIcon@1886615923$kPublicFolderIcon@1886741094$kQuestionMarkIcon@1903519091$kRecentApplicationsFolderIcon@1918988400$kRecentDocumentsFolderIcon@1919184739$kRecentItemsIcon@1919118964$kRecentServersFolderIcon@1920168566$kRightContainerArrowIcon@1919115634$kScriptingAdditionsFolderIcon@-999070862$kScriptsFolderIcon@1935897284$kSharedBadgeIcon@1935828071$kSharedFolderIcon@1936221804$kSharedFolderIconResource@-3978$kSharedLibrariesFolderIcon@-999528094$kSharingPrivsNotApplicableIcon@1936223841$kSharingPrivsReadOnlyIcon@1936224879$kSharingPrivsReadWriteIcon@1936224887$kSharingPrivsUnknownIcon@1936225643$kSharingPrivsWritableIcon@2003986804$kShortcutIcon@1936224884$kShutdownItemsDisabledFolderIcon@1936221252$kShutdownItemsFolderIcon@1936221286$kSortAscendingIcon@1634954852$kSortDescendingIcon@1685286500$kSoundFileIcon@1936091500$kSpeakableItemsFolder@1936747369$kStartupFolderIconResource@-3981$kStartupItemsDisabledFolderIcon@1937011268$kStartupItemsFolderIcon@1937011316$kSystemExtensionDisabledFolderIcon@1835098948$kSystemFolderIcon@1835098995$kSystemFolderIconResource@-3983$kSystemIconsCreator@1835098995$kSystemSuitcaseIcon@2054388083$kTextEncodingsFolderIcon@-999004808$kToolbarAdvancedIcon@1952604534$kToolbarApplicationsFolderIcon@1950445683$kToolbarCustomizeIcon@1952675187$kToolbarDeleteIcon@1952736620$kToolbarDesktopFolderIcon@1950643051$kToolbarDocumentsFolderIcon@1950642019$kToolbarDownloadsFolderIcon@1950644078$kToolbarFavoritesIcon@1952866678$kToolbarHomeIcon@1953001325$kToolbarInfoIcon@1952606574$kToolbarLabelsIcon@1952607330$kToolbarLibraryFolderIcon@1951164770$kToolbarMovieFolderIcon@1951231862$kToolbarMusicFolderIcon@1951233395$kToolbarPicturesFolderIcon@1951426915$kToolbarPublicFolderIcon@1951429986$kToolbarSitesFolderIcon@1951626355$kToolbarUtilitiesFolderIcon@1951757420$kTrashIcon@1953657704$kTrashIconResource@-3993$kTrueTypeFlatFontIcon@1936092788$kTrueTypeFontIcon@1952868716$kTrueTypeMultiFlatFontIcon@1953784678$kUnknownFSObjectIcon@1970169459$kUnlockedIcon@1970037611$kUserFolderIcon@1969646692$kUserIDiskIcon@1969517419$kUserIcon@1970496882$kUsersFolderIcon@1970500292$kUtilitiesFolderIcon@1970563524$kVoicesFolderIcon@1719037795$kWorkgroupFolderIcon@2003201124$mountedFolderIconResource@-3977$openFolderIconResource@-3997$ownedFolderIconResource@-3980$preferencesFolderIconResource@-3974$printMonitorFolderIconResource@-3975$privateFolderIconResource@-3994$sharedFolderIconResource@-3978$startupFolderIconResource@-3981$systemFolderIconResource@-3983$trashIconResource@-3993$"""
misc.update(
    {
        "LSHandlerOptions": NewType("LSHandlerOptions", int),
        "LSRolesMask": NewType("LSRolesMask", int),
        "LSRequestedInfo": NewType("LSRequestedInfo", int),
        "LSItemInfoFlags": NewType("LSItemInfoFlags", int),
        "LSLaunchFlags": NewType("LSLaunchFlags", int),
        "LSAcceptanceFlags": NewType("LSAcceptanceFlags", int),
    }
)
misc.update({})
functions = {
    "LSSharedFileListItemCopyDisplayName": (
        b"^{__CFString=}^{OpaqueLSSharedFileListItemRef=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "_LSCopyAllApplicationURLs": (
        b"v^@",
        "",
        {"arguments": {0: {"already_retained": True, "type_modifier": "o"}}},
    ),
    "LSCopyItemInfoForRef": (
        b"i^{FSRef=[80C]}I^{LSItemInfoRecord=III^{__CFString=}}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {0: {"type_modifier": "n"}, 2: {"type_modifier": "o"}},
        },
    ),
    "GetIconRefFromTypeInfo": (
        b"sII^{__CFString=}^{__CFString=}I^^{OpaqueIconRef=}",
        "",
        {"arguments": {5: {"type_modifier": "o"}}},
    ),
    "ReadIconFromFSRef": (
        b"i^{FSRef=[80C]}^^^{IconFamilyResource=Ii[1{IconFamilyElement=Ii[1C]}]}",
        "",
        {"arguments": {0: {"type_modifier": "n"}}},
    ),
    "LSSharedFileListRemoveAllItems": (b"i^{OpaqueLSSharedFileListRef=}",),
    "LSCopyItemAttribute": (
        b"i^{FSRef=[80C]}I^{__CFString=}^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                0: {"type_modifier": "n"},
                3: {"already_cfretained": True, "type_modifier": "o"},
            },
        },
    ),
    "LSSharedFileListItemMove": (
        b"i^{OpaqueLSSharedFileListRef=}^{OpaqueLSSharedFileListItemRef=}^{OpaqueLSSharedFileListItemRef=}",
    ),
    "LSSetDefaultRoleHandlerForContentType": (b"i^{__CFString=}I^{__CFString=}",),
    "LSSetHandlerOptionsForContentType": (b"i^{__CFString=}I",),
    "LSSharedFileListGetTypeID": (b"Q",),
    "LSInit": (b"iI",),
    "LSCopyDefaultHandlerForURLScheme": (
        b"^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "LSCopyAllRoleHandlersForContentType": (
        b"^{__CFArray=}^{__CFString=}I",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "IsDataAvailableInIconRef": (b"ZI^{OpaqueIconRef=}",),
    "IsValidIconRef": (b"Z^{OpaqueIconRef=}",),
    "LSCanRefAcceptItem": (
        b"i^{FSRef=[80C]}^{FSRef=[80C]}II^Z",
        "",
        {
            "arguments": {
                0: {"type_modifier": "n"},
                1: {"type_modifier": "n"},
                4: {"type_modifier": "o"},
            }
        },
    ),
    "LSCopyKindStringForTypeInfo": (
        b"iII^{__CFString=}^^{__CFString=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {3: {"already_cfretained": True, "type_modifier": "o"}},
        },
    ),
    "UTTypeCopyPreferredTagWithClass": (
        b"^{__CFString=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "LSSetExtensionHiddenForURL": (b"i^{__CFURL=}Z",),
    "LSOpenFSRef": (
        b"i^{FSRef=[80C]}^{FSRef=[80C]}",
        "",
        {"arguments": {0: {"type_modifier": "n"}, 1: {"type_modifier": "o"}}},
    ),
    "LSSharedFileListInsertItemFSRef": (
        b"^{OpaqueLSSharedFileListItemRef=}^{OpaqueLSSharedFileListRef=}^{OpaqueLSSharedFileListItemRef=}^{__CFString=}^{OpaqueIconRef=}^{FSRef=[80C]}^{__CFDictionary=}^{__CFArray=}",
        "",
        {"arguments": {4: {"type_modifier": "n"}}},
    ),
    "LSCopyItemAttributes": (
        b"i^{FSRef=[80C]}I^{__CFArray=}^^{__CFDictionary=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {0: {"type_modifier": "n"}, 3: {"type_modifier": "o"}},
        },
    ),
    "LSSharedFileListItemSetProperty": (
        b"i^{OpaqueLSSharedFileListItemRef=}^{__CFString=}@",
    ),
    "UTTypeCreateAllIdentifiersForTag": (
        b"^{__CFArray=}^{__CFString=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "UTTypeCopyDeclaringBundleURL": (
        b"^{__CFURL=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "LSGetHandlerOptionsForContentType": (b"I^{__CFString=}",),
    "LSTerm": (b"i",),
    "LSSharedFileListItemCopyProperty": (
        b"@^{OpaqueLSSharedFileListItemRef=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "UpdateIconRef": (b"s^{OpaqueIconRef=}",),
    "LSGetApplicationForInfo": (
        b"iII^{__CFString=}I^{FSRef=[80C]}^^{__CFURL=}",
        "",
        {
            "arguments": {
                4: {"type_modifier": "o"},
                5: {"already_cfretained": True, "type_modifier": "o"},
            }
        },
    ),
    "LSSharedFileListItemGetTypeID": (b"Q",),
    "GetIconRefFromComponent": (
        b"i^{ComponentRecord=[1q]}^^{OpaqueIconRef=}",
        "",
        {"arguments": {1: {"type_modifier": "o"}}},
    ),
    "UTTypeCopyDeclaration": (
        b"^{__CFDictionary=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "LSSharedFileListSetProperty": (b"i^{OpaqueLSSharedFileListRef=}^{__CFString=}@",),
    "LSSharedFileListItemCopyResolvedURL": (
        b"^{__CFURL=}^{OpaqueLSSharedFileListItemRef=}I^^{__CFError=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "LSSharedFileListRemoveObserver": (
        b"v^{OpaqueLSSharedFileListRef=}^{__CFRunLoop=}^{__CFString=}^?^v",
        "",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{OpaqueLSSharedFileListRef=}"},
                            1: {"type": b"^v"},
                        },
                    }
                }
            }
        },
    ),
    "RegisterIconRefFromFSRef": (
        b"iII^{FSRef=[80C]}^^{OpaqueIconRef=}",
        "",
        {"arguments": {2: {"type_modifier": "n"}}},
    ),
    "LSCopyApplicationForMIMEType": (
        b"i^{__CFString=}I^^{__CFURL=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True, "type_modifier": "o"}},
        },
    ),
    "ReleaseIconRef": (b"s^{OpaqueIconRef=}",),
    "UTTypeCreatePreferredIdentifierForTag": (
        b"^{__CFString=}^{__CFString=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "LSSharedFileListItemResolve": (
        b"i^{OpaqueLSSharedFileListItemRef=}I^^{__CFURL=}^{FSRef=[80C]}",
        "",
        {
            "arguments": {
                2: {"already_cfretained": True, "type_modifier": "o"},
                3: {"type_modifier": "o"},
            }
        },
    ),
    "GetIconRefFromIconFamilyPtr": (
        b"i^{IconFamilyResource=Ii[1{IconFamilyElement=Ii[1C]}]}q^^{OpaqueIconRef=}",
        "",
        {"arguments": {0: {"type_modifier": "n"}, 2: {"type_modifier": "o"}}},
    ),
    "LSSharedFileListCreate": (
        b"^{OpaqueLSSharedFileListRef=}^{__CFAllocator=}^{__CFString=}@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "OverrideIconRef": (b"s^{OpaqueIconRef=}^{OpaqueIconRef=}",),
    "LSSharedFileListCopyProperty": (
        b"@^{OpaqueLSSharedFileListRef=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "IsIconRefComposite": (
        b"s^{OpaqueIconRef=}^^{OpaqueIconRef=}^^{OpaqueIconRef=}",
        "",
        {"arguments": {1: {"type_modifier": "o"}, 2: {"type_modifier": "o"}}},
    ),
    "LSCanURLAcceptURL": (
        b"i^{__CFURL=}^{__CFURL=}II^Z",
        "",
        {"arguments": {4: {"type_modifier": "o"}}},
    ),
    "LSCopyKindStringForRef": (
        b"i^{FSRef=[80C]}^^{__CFString=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                0: {"type_modifier": "n"},
                1: {"already_cfretained": True, "type_modifier": "o"},
            },
        },
    ),
    "LSSharedFileListSetAuthorization": (
        b"i^{OpaqueLSSharedFileListRef=}^{AuthorizationOpaqueRef=}",
    ),
    "LSOpenItemsWithRole": (
        b"i^{FSRef=[80C]}qI^{AEKeyDesc=I{AEDesc=I^^{OpaqueAEDataStorageType=}}}^{LSApplicationParameters=qI^{FSRef=[80C]}^v^{__CFDictionary=}^{__CFArray=}^{AEDesc=I^^{OpaqueAEDataStorageType=}}}^{ProcessSerialNumber=II}q",
        "",
        {
            "arguments": {
                0: {"c_array_length_in_arg": 1, "type_modifier": "n"},
                3: {"type_modifier": "n"},
                4: {"type_modifier": "n"},
                5: {"c_array_length_in_arg": 6, "type_modifier": "o"},
            }
        },
    ),
    "LSSharedFileListGetSeedValue": (b"I^{OpaqueLSSharedFileListRef=}",),
    "LSOpenApplication": (
        b"i^{LSApplicationParameters=qI^{FSRef=[80C]}^v^{__CFDictionary=}^{__CFArray=}^{AEDesc=I^^{OpaqueAEDataStorageType=}}}^{ProcessSerialNumber=II}",
        "",
        {"arguments": {0: {"type_modifier": "n"}, 1: {"type_modifier": "o"}}},
    ),
    "LSGetApplicationForItem": (
        b"i^{FSRef=[80C]}I^{FSRef=[80C]}^^{__CFURL=}",
        "",
        {
            "arguments": {
                0: {"type_modifier": "n"},
                2: {"type_modifier": "o"},
                3: {"already_cfretained": True, "type_modifier": "o"},
            }
        },
    ),
    "LSSetDefaultHandlerForURLScheme": (b"i^{__CFString=}^{__CFString=}",),
    "GetIconRef": (
        b"ssII^^{OpaqueIconRef=}",
        "",
        {"arguments": {3: {"type_modifier": "o"}}},
    ),
    "LSRegisterURL": (b"i^{__CFURL=}Z",),
    "GetIconRefOwners": (
        b"s^{OpaqueIconRef=}^S",
        "",
        {"arguments": {1: {"type_modifier": "o"}}},
    ),
    "LSCopyAllHandlersForURLScheme": (
        b"^{__CFArray=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "LSCopyDefaultApplicationURLForContentType": (
        b"^{__CFURL=}^{__CFString=}I^^{__CFError=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "UTTypeIsDynamic": (b"Z^{__CFString=}",),
    "AcquireIconRef": (b"s^{OpaqueIconRef=}",),
    "LSSharedFileListItemCopyIconRef": (
        b"^{OpaqueIconRef=}^{OpaqueLSSharedFileListItemRef=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "UTGetOSTypeFromString": (b"I^{__CFString=}",),
    "LSGetApplicationForURL": (
        b"i^{__CFURL=}I^{FSRef=[80C]}^^{__CFURL=}",
        "",
        {
            "arguments": {
                2: {"type_modifier": "o"},
                3: {"already_cfretained": True, "type_modifier": "o"},
            }
        },
    ),
    "LSSharedFileListInsertItemURL": (
        b"^{OpaqueLSSharedFileListItemRef=}^{OpaqueLSSharedFileListRef=}^{OpaqueLSSharedFileListItemRef=}^{__CFString=}^{OpaqueIconRef=}^{__CFURL=}^{__CFDictionary=}^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "LSOpenURLsWithRole": (
        b"i^{__CFArray=}I^{AEKeyDesc=I{AEDesc=I^^{OpaqueAEDataStorageType=}}}^{LSApplicationParameters=qI^{FSRef=[80C]}^v^{__CFDictionary=}^{__CFArray=}^{AEDesc=I^^{OpaqueAEDataStorageType=}}}^{ProcessSerialNumber=II}q",
        "",
        {
            "arguments": {
                2: {"type_modifier": "n"},
                3: {"type_modifier": "n"},
                4: {"c_array_length_in_arg": 5, "type_modifier": "o"},
            }
        },
    ),
    "LSCopyDefaultRoleHandlerForContentType": (
        b"^{__CFString=}^{__CFString=}I",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "UnregisterIconRef": (b"sII",),
    "LSOpenFromURLSpec": (
        b"i^{LSLaunchURLSpec=^{__CFURL=}^{__CFArray=}^{AEDesc=I^^{OpaqueAEDataStorageType=}}I^v}^^{__CFURL=}",
        "",
        {
            "arguments": {
                0: {"type_modifier": "n"},
                1: {"already_cfretained": True, "type_modifier": "o"},
            }
        },
    ),
    "UTTypeConformsTo": (b"Z^{__CFString=}^{__CFString=}",),
    "SetCustomIconsEnabled": (b"ssZ",),
    "LSRegisterFSRef": (
        b"i^{FSRef=[80C]}Z",
        "",
        {"arguments": {0: {"type_modifier": "n"}}},
    ),
    "LSSetItemAttribute": (
        b"i^{FSRef=[80C]}I^{__CFString=}@",
        "",
        {"arguments": {0: {"type_modifier": "n"}}},
    ),
    "UTCreateStringForOSType": (
        b"^{__CFString=}I",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "RemoveIconRefOverride": (b"s^{OpaqueIconRef=}",),
    "LSCopyDisplayNameForRef": (
        b"i^{FSRef=[80C]}^^{__CFString=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                0: {"type_modifier": "n"},
                1: {"already_cfretained": True, "type_modifier": "o"},
            },
        },
    ),
    "CompositeIconRef": (
        b"s^{OpaqueIconRef=}^{OpaqueIconRef=}^^{OpaqueIconRef=}",
        "",
        {"arguments": {2: {"type_modifier": "o"}}},
    ),
    "UTTypeEqual": (b"Z^{__CFString=}^{__CFString=}",),
    "UTTypeCopyAllTagsWithClass": (
        b"^{__CFArray=}^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "LSCopyKindStringForMIMEType": (
        b"i^{__CFString=}^^{__CFString=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True, "type_modifier": "o"}},
        },
    ),
    "RegisterIconRefFromIconFamily": (
        b"sII^^{IconFamilyResource=Ii[1{IconFamilyElement=Ii[1C]}]}^^{OpaqueIconRef=}",
    ),
    "UTTypeIsDeclared": (b"Z^{__CFString=}",),
    "LSCopyDisplayNameForURL": (
        b"i^{__CFURL=}^^{__CFString=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True, "type_modifier": "o"}},
        },
    ),
    "GetIconRefFromFolder": (
        b"ssiicc^^{OpaqueIconRef=}",
        "",
        {"arguments": {5: {"type_modifier": "o"}}},
    ),
    "LSSetExtensionHiddenForRef": (
        b"i^{FSRef=[80C]}Z",
        "",
        {"arguments": {0: {"type_modifier": "n"}}},
    ),
    "LSGetExtensionInfo": (
        b"iQ^T^Q",
        "",
        {
            "arguments": {
                1: {"c_array_length_in_arg": 0, "type_modifier": "n"},
                2: {"type_modifier": "o"},
            }
        },
    ),
    "LSCopyDefaultApplicationURLForURL": (
        b"^{__CFURL=}^{__CFURL=}I^^{__CFError=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "GetIconRefFromFileInfo": (
        b"i^{FSRef=[80C]}Q^TI^{FSCatalogInfo=SsIICCCC{UTCDateTime=SIS}{UTCDateTime=SIS}{UTCDateTime=SIS}{UTCDateTime=SIS}{UTCDateTime=SIS}{FSPermissionInfo=IICCS^{__FSFileSecurity=}}[16C][16C]QQQQII}I^^{OpaqueIconRef=}^s",
        "",
        {
            "arguments": {
                0: {"type_modifier": "n"},
                2: {"c_array_length_in_arg": 1, "type_modifier": "n"},
                4: {"null_accepted": True, "type_modifier": "n"},
                6: {"type_modifier": "o"},
                7: {"type_modifier": "o"},
            }
        },
    ),
    "UTTypeCopyDescription": (
        b"^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "LSCopyApplicationURLsForBundleIdentifier": (
        b"^{__CFArray=}^{__CFString=}^^{__CFError=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "GetCustomIconsEnabled": (b"ss^Z", "", {"arguments": {1: {"type_modifier": "o"}}}),
    "LSCopyItemInfoForURL": (
        b"i^{__CFURL=}I^{LSItemInfoRecord=III^{__CFString=}}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"type_modifier": "o"}},
        },
    ),
    "LSFindApplicationForInfo": (
        b"iI^{__CFString=}^{__CFString=}^{FSRef=[80C]}^^{__CFURL=}",
        "",
        {
            "arguments": {
                3: {"type_modifier": "o"},
                4: {"already_cfretained": True, "type_modifier": "o"},
            }
        },
    ),
    "LSOpenFromRefSpec": (
        b"i^{LSLaunchFSRefSpec=^{FSRef=[80C]}Q^{FSRef=[80C]}^{AEDesc=I^^{OpaqueAEDataStorageType=}}I^v}^{FSRef=[80C]}",
        "",
        {"arguments": {0: {"type_modifier": "n"}, 1: {"type_modifier": "o"}}},
    ),
    "LSSharedFileListItemRemove": (
        b"i^{OpaqueLSSharedFileListRef=}^{OpaqueLSSharedFileListItemRef=}",
    ),
    "LSCopyKindStringForURL": (
        b"i^{__CFURL=}^^{__CFString=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True, "type_modifier": "o"}},
        },
    ),
    "LSCopyApplicationURLsForURL": (
        b"^{__CFArray=}^{__CFURL=}I",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "LSOpenCFURLRef": (
        b"i^{__CFURL=}^^{__CFURL=}",
        "",
        {"arguments": {1: {"already_cfretained": True, "type_modifier": "o"}}},
    ),
    "LSSharedFileListCopySnapshot": (
        b"^{__CFArray=}^{OpaqueLSSharedFileListRef=}^I",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"type_modifier": "o"}},
        },
    ),
    "LSSharedFileListAddObserver": (
        b"v^{OpaqueLSSharedFileListRef=}^{__CFRunLoop=}^{__CFString=}^?^v",
        "",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^{OpaqueLSSharedFileListRef=}"},
                            1: {"type": b"^v"},
                        },
                    },
                    "callable_retained": True,
                }
            }
        },
    ),
    "LSSharedFileListItemGetID": (b"I^{OpaqueLSSharedFileListItemRef=}",),
}
aliases = {
    "mountedFolderIconResource": "kMountedFolderIconResource",
    "genericFolderIconResource": "kGenericFolderIconResource",
    "genericApplicationIconResource": "kGenericApplicationIconResource",
    "genericFileServerIconResource": "kGenericFileServerIconResource",
    "printMonitorFolderIconResource": "kPrintMonitorFolderIconResource",
    "sharedFolderIconResource": "kSharedFolderIconResource",
    "openFolderIconResource": "kOpenFolderIconResource",
    "controlPanelFolderIconResource": "kControlPanelFolderIconResource",
    "desktopIconResource": "kDesktopIconResource",
    "floppyIconResource": "kFloppyIconResource",
    "genericSuitcaseIconResource": "kGenericSuitcaseIconResource",
    "fontsFolderIconResource": "kFontsFolderIconResource",
    "kLSInvalidExtensionIndex": "ULONG_MAX",
    "genericEditionFileIconResource": "kGenericEditionFileIconResource",
    "genericQueryDocumentIconResource": "kGenericQueryDocumentIconResource",
    "genericMoverObjectIconResource": "kGenericMoverObjectIconResource",
    "extensionsFolderIconResource": "kExtensionsFolderIconResource",
    "genericRAMDiskIconResource": "kGenericRAMDiskIconResource",
    "dropFolderIconResource": "kDropFolderIconResource",
    "genericHardDiskIconResource": "kGenericHardDiskIconResource",
    "genericDocumentIconResource": "kGenericDocumentIconResource",
    "appleMenuFolderIconResource": "kAppleMenuFolderIconResource",
    "systemFolderIconResource": "kSystemFolderIconResource",
    "genericDeskAccessoryIconResource": "kGenericDeskAccessoryIconResource",
    "privateFolderIconResource": "kPrivateFolderIconResource",
    "preferencesFolderIconResource": "kPreferencesFolderIconResource",
    "fullTrashIconResource": "kFullTrashIconResource",
    "trashIconResource": "kTrashIconResource",
    "genericPreferencesIconResource": "kGenericPreferencesIconResource",
    "genericStationeryIconResource": "kGenericStationeryIconResource",
    "genericExtensionIconResource": "kGenericExtensionIconResource",
    "ownedFolderIconResource": "kOwnedFolderIconResource",
    "startupFolderIconResource": "kStartupFolderIconResource",
    "genericCDROMIconResource": "kGenericCDROMIconResource",
    "kInternationResourcesIcon": "kInternationalResourcesIcon",
}
cftypes = [
    (
        "LSSharedFileListItemRef",
        b"^{OpaqueLSSharedFileListItemRef=}",
        "LSSharedFileListItemGetTypeID",
        None,
    ),
    (
        "LSSharedFileListRef",
        b"^{OpaqueLSSharedFileListRef=}",
        "LSSharedFileListGetTypeID",
        None,
    ),
]
misc.update({"IconRef": objc.createOpaquePointerType("IconRef", b"^{OpaqueIconRef=}")})
expressions = {}

# END OF FILE



# This file is generated by objective.metadata
#
# Last update: Sun Feb 20 18:46:06 2022
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
misc.update(
    {
        "ScriptCodeRun": objc.createStructType(
            "CoreServices.CarbonCore.ScriptCodeRun",
            b"{ScriptCodeRun=Qs}",
            ["offset", "script"],
        ),
        "NumFormatStringRec": objc.createStructType(
            "CoreServices.CarbonCore.NumFormatStringRec",
            b"{NumFormatString=CC[254c]}",
            ["fLength", "fVersion", "data"],
        ),
        "UnicodeMapping": objc.createStructType(
            "CoreServices.CarbonCore.UnicodeMapping",
            b"{UnicodeMapping=IIi}",
            ["unicodeEncoding", "otherEncoding", "mappingVersion"],
        ),
        "TECConversionInfo": objc.createStructType(
            "CoreServices.CarbonCore.TECConversionInfo",
            b"{TECConversionInfo=IISS}",
            ["sourceEncoding", "destinationEncoding", "reserved1", "reserved2"],
        ),
        "LocaleAndVariant": objc.createStructType(
            "CoreServices.CarbonCore.LocaleAndVariant",
            b"{LocaleAndVariant=^{OpaqueLocaleRef=}I}",
            ["locale", "opVariant"],
        ),
        "TextEncodingRun": objc.createStructType(
            "CoreServices.CarbonCore.TextEncodingRun",
            b"{TextEncodingRun=QI}",
            ["offset", "textEncoding"],
        ),
        "TECInfo": objc.createStructType(
            "CoreServices.CarbonCore.TECInfo",
            b"{TECInfo=SSIII[32C][32C]SS}",
            [
                "format",
                "tecVersion",
                "tecTextConverterFeatures",
                "tecUnicodeConverterFeatures",
                "tecTextCommonFeatures",
                "tecTextEncodingsFolderName",
                "tecExtensionFileName",
                "tecLowestTEFileVersion",
                "tecHighestTEFileVersion",
            ],
        ),
        "Nanoseconds": objc.createStructType(
            "CoreServices.CarbonCore.Nanoseconds", b"{UnsignedWide=II}", ["lo", "hi"]
        ),
    }
)
constants = """$$"""
enums = """$gestaltArm@20$kBig5_BasicVariant@0$kBig5_DOSVariant@3$kBig5_ETenVariant@2$kBig5_StandardVariant@1$kCSDiskSpaceRecoveryOptionNoUI@1$kDOSJapanesePalmVariant@1$kDOSJapaneseStandardVariant@0$kEUC_CN_BasicVariant@0$kEUC_CN_DOSVariant@1$kEUC_KR_BasicVariant@0$kEUC_KR_DOSVariant@1$kFSAllowConcurrentAsyncIOBit@3$kHebrewFigureSpaceVariant@1$kHebrewStandardVariant@0$kISOLatin1MusicCDVariant@1$kISOLatin1StandardVariant@0$kISOLatinArabicExplicitOrderVariant@2$kISOLatinArabicImplicitOrderVariant@0$kISOLatinArabicVisualOrderVariant@1$kISOLatinHebrewExplicitOrderVariant@2$kISOLatinHebrewImplicitOrderVariant@0$kISOLatinHebrewVisualOrderVariant@1$kJapaneseBasicVariant@2$kJapanesePostScriptPrintVariant@4$kJapanesePostScriptScrnVariant@3$kJapaneseStandardVariant@0$kJapaneseStdNoVerticalsVariant@1$kJapaneseVertAtKuPlusTenVariant@5$kLocaleAllPartsMask@63$kLocaleAndVariantNameMask@3$kLocaleLanguageMask@1$kLocaleLanguageVariantMask@2$kLocaleNameMask@1$kLocaleOperationVariantNameMask@2$kLocaleRegionMask@16$kLocaleRegionVariantMask@32$kLocaleScriptMask@4$kLocaleScriptVariantMask@8$kMacArabicAlBayanVariant@3$kMacArabicStandardVariant@0$kMacArabicThuluthVariant@2$kMacArabicTrueTypeVariant@1$kMacCroatianCurrencySignVariant@1$kMacCroatianDefaultVariant@0$kMacCroatianEuroSignVariant@2$kMacCyrillicCurrSignStdVariant@1$kMacCyrillicCurrSignUkrVariant@2$kMacCyrillicDefaultVariant@0$kMacCyrillicEuroSignVariant@3$kMacFarsiStandardVariant@0$kMacFarsiTrueTypeVariant@1$kMacGreekDefaultVariant@0$kMacGreekEuroSignVariant@2$kMacGreekNoEuroSignVariant@1$kMacHebrewFigureSpaceVariant@1$kMacHebrewStandardVariant@0$kMacIcelandicStandardVariant@0$kMacIcelandicStdCurrSignVariant@2$kMacIcelandicStdDefaultVariant@0$kMacIcelandicStdEuroSignVariant@4$kMacIcelandicTTCurrSignVariant@3$kMacIcelandicTTDefaultVariant@1$kMacIcelandicTTEuroSignVariant@5$kMacIcelandicTrueTypeVariant@1$kMacJapaneseBasicVariant@2$kMacJapanesePostScriptPrintVariant@4$kMacJapanesePostScriptScrnVariant@3$kMacJapaneseStandardVariant@0$kMacJapaneseStdNoVerticalsVariant@1$kMacJapaneseVertAtKuPlusTenVariant@5$kMacRomanCurrencySignVariant@1$kMacRomanDefaultVariant@0$kMacRomanEuroSignVariant@2$kMacRomanLatin1CroatianVariant@8$kMacRomanLatin1DefaultVariant@0$kMacRomanLatin1IcelandicVariant@11$kMacRomanLatin1RomanianVariant@14$kMacRomanLatin1StandardVariant@2$kMacRomanLatin1TurkishVariant@6$kMacRomanStandardVariant@0$kMacRomanianCurrencySignVariant@1$kMacRomanianDefaultVariant@0$kMacRomanianEuroSignVariant@2$kMacVT100CurrencySignVariant@1$kMacVT100DefaultVariant@0$kMacVT100EuroSignVariant@2$kShiftJIS_BasicVariant@0$kShiftJIS_DOSVariant@1$kShiftJIS_MusicCDVariant@2$kTECAddFallbackInterruptBit@7$kTECAddFallbackInterruptMask@128$kTECAddForceASCIIChangesBit@4$kTECAddForceASCIIChangesMask@16$kTECAddTextRunHeuristicsBit@6$kTECAddTextRunHeuristicsMask@64$kTECChinesePluginSignature@1887070319$kTECDisableFallbacksBit@16$kTECDisableFallbacksMask@65536$kTECDisableLooseMappingsBit@17$kTECDisableLooseMappingsMask@131072$kTECFallbackTextLengthFixBit@1$kTECFallbackTextLengthFixMask@2$kTECInfoCurrentFormat@2$kTECInternetNameDefaultUsageMask@0$kTECInternetNameStrictUsageMask@1$kTECInternetNameTolerantUsageMask@2$kTECJapanesePluginSignature@1886023790$kTECKeepInfoFixBit@0$kTECKeepInfoFixMask@1$kTECKoreanPluginSignature@1886089074$kTECPreferredEncodingFixBit@5$kTECPreferredEncodingFixMask@32$kTECSignature@1701733238$kTECTextRunBitClearFixBit@2$kTECTextRunBitClearFixMask@4$kTECTextToUnicodeScanFixBit@3$kTECTextToUnicodeScanFixMask@8$kTECUnicodePluginSignature@1886744169$kTEC_MIBEnumDontCare@-1$kTextCenter@1$kTextEncodingANSEL@1537$kTextEncodingBaseName@1$kTextEncodingBig5@2563$kTextEncodingBig5_E@2569$kTextEncodingBig5_HKSCS_1999@2566$kTextEncodingCNS_11643_92_P1@1617$kTextEncodingCNS_11643_92_P2@1618$kTextEncodingCNS_11643_92_P3@1619$kTextEncodingDOSArabic@1049$kTextEncodingDOSBalticRim@1030$kTextEncodingDOSCanadianFrench@1048$kTextEncodingDOSChineseSimplif@1057$kTextEncodingDOSChineseTrad@1059$kTextEncodingDOSCyrillic@1043$kTextEncodingDOSGreek@1029$kTextEncodingDOSGreek1@1041$kTextEncodingDOSGreek2@1052$kTextEncodingDOSHebrew@1047$kTextEncodingDOSIcelandic@1046$kTextEncodingDOSJapanese@1056$kTextEncodingDOSKorean@1058$kTextEncodingDOSLatin1@1040$kTextEncodingDOSLatin2@1042$kTextEncodingDOSLatinUS@1024$kTextEncodingDOSNordic@1050$kTextEncodingDOSPortuguese@1045$kTextEncodingDOSRussian@1051$kTextEncodingDOSThai@1053$kTextEncodingDOSTurkish@1044$kTextEncodingDefaultFormat@0$kTextEncodingDefaultVariant@0$kTextEncodingEBCDIC_CP037@3074$kTextEncodingEBCDIC_LatinCore@3073$kTextEncodingEBCDIC_US@3073$kTextEncodingEUC_CN@2352$kTextEncodingEUC_JP@2336$kTextEncodingEUC_KR@2368$kTextEncodingEUC_TW@2353$kTextEncodingFormatName@3$kTextEncodingFullName@0$kTextEncodingGBK_95@1585$kTextEncodingGB_18030_2000@1586$kTextEncodingGB_18030_2005@1586$kTextEncodingGB_2312_80@1584$kTextEncodingHZ_GB_2312@2565$kTextEncodingISO10646_1993@257$kTextEncodingISOLatin1@513$kTextEncodingISOLatin10@528$kTextEncodingISOLatin2@514$kTextEncodingISOLatin3@515$kTextEncodingISOLatin4@516$kTextEncodingISOLatin5@521$kTextEncodingISOLatin6@522$kTextEncodingISOLatin7@525$kTextEncodingISOLatin8@526$kTextEncodingISOLatin9@527$kTextEncodingISOLatinArabic@518$kTextEncodingISOLatinCyrillic@517$kTextEncodingISOLatinGreek@519$kTextEncodingISOLatinHebrew@520$kTextEncodingISO_2022_CN@2096$kTextEncodingISO_2022_CN_EXT@2097$kTextEncodingISO_2022_JP@2080$kTextEncodingISO_2022_JP_1@2082$kTextEncodingISO_2022_JP_2@2081$kTextEncodingISO_2022_JP_3@2083$kTextEncodingISO_2022_KR@2112$kTextEncodingJIS_C6226_78@1572$kTextEncodingJIS_X0201_76@1568$kTextEncodingJIS_X0208_83@1569$kTextEncodingJIS_X0208_90@1570$kTextEncodingJIS_X0212_90@1571$kTextEncodingJIS_X0213_MenKuTen@1577$kTextEncodingKOI8_R@2562$kTextEncodingKOI8_U@2568$kTextEncodingKSC_5601_87@1600$kTextEncodingKSC_5601_92_Johab@1601$kTextEncodingMacArabic@4$kTextEncodingMacArmenian@24$kTextEncodingMacBengali@13$kTextEncodingMacBurmese@19$kTextEncodingMacCeltic@39$kTextEncodingMacCentralEurRoman@29$kTextEncodingMacChineseSimp@25$kTextEncodingMacChineseTrad@2$kTextEncodingMacCroatian@36$kTextEncodingMacCyrillic@7$kTextEncodingMacDevanagari@9$kTextEncodingMacDingbats@34$kTextEncodingMacEastEurRoman@29$kTextEncodingMacEthiopic@28$kTextEncodingMacExtArabic@31$kTextEncodingMacFarsi@140$kTextEncodingMacGaelic@40$kTextEncodingMacGeez@28$kTextEncodingMacGeorgian@23$kTextEncodingMacGreek@6$kTextEncodingMacGujarati@11$kTextEncodingMacGurmukhi@10$kTextEncodingMacHFS@255$kTextEncodingMacHebrew@5$kTextEncodingMacIcelandic@37$kTextEncodingMacInuit@236$kTextEncodingMacJapanese@1$kTextEncodingMacKannada@16$kTextEncodingMacKeyboardGlyphs@41$kTextEncodingMacKhmer@20$kTextEncodingMacKorean@3$kTextEncodingMacLaotian@22$kTextEncodingMacMalayalam@17$kTextEncodingMacMongolian@27$kTextEncodingMacOriya@12$kTextEncodingMacRSymbol@8$kTextEncodingMacRoman@0$kTextEncodingMacRomanLatin1@2564$kTextEncodingMacRomanian@38$kTextEncodingMacSimpChinese@25$kTextEncodingMacSinhalese@18$kTextEncodingMacSymbol@33$kTextEncodingMacTamil@14$kTextEncodingMacTelugu@15$kTextEncodingMacThai@21$kTextEncodingMacTibetan@26$kTextEncodingMacTradChinese@2$kTextEncodingMacTurkish@35$kTextEncodingMacUkrainian@152$kTextEncodingMacUnicode@126$kTextEncodingMacUninterp@32$kTextEncodingMacVT100@252$kTextEncodingMacVietnamese@30$kTextEncodingMultiRun@4095$kTextEncodingNextStepJapanese@2818$kTextEncodingNextStepLatin@2817$kTextEncodingShiftJIS@2561$kTextEncodingShiftJIS_X0213@1576$kTextEncodingShiftJIS_X0213_00@1576$kTextEncodingUS_ASCII@1536$kTextEncodingUnicodeDefault@256$kTextEncodingUnicodeV10_0@276$kTextEncodingUnicodeV11_0@277$kTextEncodingUnicodeV12_1@278$kTextEncodingUnicodeV13_0@279$kTextEncodingUnicodeV1_1@257$kTextEncodingUnicodeV2_0@259$kTextEncodingUnicodeV2_1@259$kTextEncodingUnicodeV3_0@260$kTextEncodingUnicodeV3_1@261$kTextEncodingUnicodeV3_2@262$kTextEncodingUnicodeV4_0@264$kTextEncodingUnicodeV5_0@266$kTextEncodingUnicodeV5_1@267$kTextEncodingUnicodeV6_0@269$kTextEncodingUnicodeV6_1@270$kTextEncodingUnicodeV6_3@272$kTextEncodingUnicodeV7_0@273$kTextEncodingUnicodeV8_0@274$kTextEncodingUnicodeV9_0@275$kTextEncodingUnknown@65535$kTextEncodingVISCII@2567$kTextEncodingVariantName@2$kTextEncodingWindowsANSI@1280$kTextEncodingWindowsArabic@1286$kTextEncodingWindowsBalticRim@1287$kTextEncodingWindowsCyrillic@1282$kTextEncodingWindowsGreek@1283$kTextEncodingWindowsHebrew@1285$kTextEncodingWindowsKoreanJohab@1296$kTextEncodingWindowsLatin1@1280$kTextEncodingWindowsLatin2@1281$kTextEncodingWindowsLatin5@1284$kTextEncodingWindowsVietnamese@1288$kTextFlushDefault@0$kTextFlushLeft@-2$kTextFlushRight@-1$kTextLanguageDontCare@-128$kTextRegionDontCare@-128$kTextScriptDontCare@-128$kUCBidiCatArabicNumber@6$kUCBidiCatBlockSeparator@8$kUCBidiCatBoundaryNeutral@19$kUCBidiCatCommonNumberSeparator@7$kUCBidiCatEuroNumber@3$kUCBidiCatEuroNumberSeparator@4$kUCBidiCatEuroNumberTerminator@5$kUCBidiCatFirstStrongIsolate@22$kUCBidiCatLeftRight@1$kUCBidiCatLeftRightEmbedding@13$kUCBidiCatLeftRightIsolate@20$kUCBidiCatLeftRightOverride@15$kUCBidiCatNonSpacingMark@18$kUCBidiCatNotApplicable@0$kUCBidiCatOtherNeutral@11$kUCBidiCatPopDirectionalFormat@17$kUCBidiCatPopDirectionalIsolate@23$kUCBidiCatRightLeft@2$kUCBidiCatRightLeftArabic@12$kUCBidiCatRightLeftEmbedding@14$kUCBidiCatRightLeftIsolate@21$kUCBidiCatRightLeftOverride@16$kUCBidiCatSegmentSeparator@9$kUCBidiCatWhitespace@10$kUCCharPropTypeBidiCategory@3$kUCCharPropTypeCombiningClass@2$kUCCharPropTypeDecimalDigitValue@4$kUCCharPropTypeGenlCategory@1$kUCGenlCatLetterLowercase@15$kUCGenlCatLetterModifier@17$kUCGenlCatLetterOther@18$kUCGenlCatLetterTitlecase@16$kUCGenlCatLetterUppercase@14$kUCGenlCatMarkEnclosing@7$kUCGenlCatMarkNonSpacing@5$kUCGenlCatMarkSpacingCombining@6$kUCGenlCatNumberDecimalDigit@8$kUCGenlCatNumberLetter@9$kUCGenlCatNumberOther@10$kUCGenlCatOtherControl@1$kUCGenlCatOtherFormat@2$kUCGenlCatOtherNotAssigned@0$kUCGenlCatOtherPrivateUse@4$kUCGenlCatOtherSurrogate@3$kUCGenlCatPunctClose@23$kUCGenlCatPunctConnector@20$kUCGenlCatPunctDash@21$kUCGenlCatPunctFinalQuote@25$kUCGenlCatPunctInitialQuote@24$kUCGenlCatPunctOpen@22$kUCGenlCatPunctOther@26$kUCGenlCatSeparatorLine@12$kUCGenlCatSeparatorParagraph@13$kUCGenlCatSeparatorSpace@11$kUCGenlCatSymbolCurrency@29$kUCGenlCatSymbolMath@28$kUCGenlCatSymbolModifier@30$kUCGenlCatSymbolOther@31$kUCHighSurrogateRangeEnd@56319$kUCHighSurrogateRangeStart@55296$kUCLowSurrogateRangeEnd@57343$kUCLowSurrogateRangeStart@56320$kUnicode16BitFormat@0$kUnicode32BitFormat@3$kUnicodeByteOrderMark@65279$kUnicodeCanonicalCompVariant@3$kUnicodeCanonicalDecompVariant@2$kUnicodeFallbackInterruptSafeMask@4$kUnicodeFallbackSequencingMask@3$kUnicodeHFSPlusCompVariant@9$kUnicodeHFSPlusDecompVariant@8$kUnicodeMaxDecomposedVariant@2$kUnicodeNoCompatibilityVariant@1$kUnicodeNoComposedVariant@3$kUnicodeNoCorporateVariant@4$kUnicodeNoSubset@0$kUnicodeNormalizationFormC@3$kUnicodeNormalizationFormD@5$kUnicodeNotAChar@65535$kUnicodeObjectReplacement@65532$kUnicodeReplacementChar@65533$kUnicodeSCSUFormat@8$kUnicodeSwappedByteOrderMark@65534$kUnicodeUTF16BEFormat@4$kUnicodeUTF16Format@0$kUnicodeUTF16LEFormat@5$kUnicodeUTF32BEFormat@6$kUnicodeUTF32Format@3$kUnicodeUTF32LEFormat@7$kUnicodeUTF7Format@1$kUnicodeUTF8Format@2$kWindowsLatin1PalmVariant@1$kWindowsLatin1StandardVariant@0$"""
misc.update({})
misc.update(
    {"kTECMacOSXDispatchTableNameString": b"ConverterPluginGetPluginDispatchTable"}
)
functions = {
    "CSBackupIsItemExcluded": (
        b"Z^{__CFURL=}^Z",
        "",
        {"arguments": {1: {"type_modifier": "o"}}},
    ),
    "CSDiskSpaceStartRecovery": (
        b"v^{__CFURL=}Qi^^{__CFUUID=}@@?",
        "",
        {
            "arguments": {
                3: {"type_modifier": "o"},
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "Z"},
                            2: {"type": "Q"},
                            3: {"type": "@"},
                        },
                    }
                },
            }
        },
    ),
    "GetTextEncodingFormat": (b"II",),
    "LocaleStringToLangAndRegionCodes": (
        b"i^t^s^s",
        "",
        {
            "arguments": {
                0: {"c_array_delimited_by_null": True, "type_modifier": "n"},
                1: {"type_modifier": "o"},
                2: {"type_modifier": "o"},
            }
        },
    ),
    "TECCreateSniffer": (
        b"i^^{OpaqueTECSnifferObjectRef=}^IQ",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                0: {"type_modifier": "o"},
                1: {"c_array_length_in_arg": 2, "type_modifier": "n"},
            },
        },
    ),
    "TECGetTextEncodingFromInternetNameOrMIB": (
        b"i^II^{__CFString=}i",
        "",
        {
            "arguments": {
                0: {"type_modifier": "o"},
            }
        },
    ),
    "GetTextEncodingFromScriptInfo": (
        b"isss^I",
        "",
        {"arguments": {3: {"type_modifier": "o"}}},
    ),
    "TECClearConverterContextInfo": (b"i^{OpaqueTECObjectRef=}",),
    "TECGetWebTextEncodings": (
        b"is^IQ^Q",
        "",
        {
            "arguments": {
                1: {"c_array_length_in_arg": (2, 3), "type_modifier": "o"},
                3: {"type_modifier": "o"},
            }
        },
    ),
    "TECCountWebTextEncodings": (
        b"is^Q",
        "",
        {"arguments": {1: {"type_modifier": "o"}}},
    ),
    "LocaleRefGetPartString": (
        b"i^{OpaqueLocaleRef=}IQ^t",
        "",
        {"arguments": {3: {"c_array_delimited_by_null": True, "type_modifier": "o"}}},
    ),
    "UCIsSurrogateLowCharacter": (b"ZT",),
    "TECCreateOneToManyConverter": (
        b"i^^{OpaqueTECObjectRef=}IQ^I",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                0: {"type_modifier": "o"},
                3: {"c_array_length_in_arg": 2, "type_modifier": "n"},
            },
        },
    ),
    "TECGetMailTextEncodings": (
        b"is^IQ^Q",
        "",
        {
            "arguments": {
                1: {"c_array_length_in_arg": (2, 3), "type_modifier": "o"},
                3: {"type_modifier": "o"},
            }
        },
    ),
    "TECSniffTextEncoding": (
        b"i^{OpaqueTECSnifferObjectRef=}^CQ^IQ^QQ^QQ",
        "",
        {
            "arguments": {
                1: {"c_array_length_in_arg": 2, "type_modifier": "n"},
                3: {"c_array_length_in_arg": 4, "type_modifier": "o"},
                5: {"c_array_length_in_arg": 6, "type_modifier": "o"},
                7: {"c_array_length_in_arg": 8, "type_modifier": "o"},
            }
        },
    ),
    "TECGetInfo": (
        b"i^^^{TECInfo=SSIII[32C][32C]SS}",
        "",
        {"arguments": {0: {"type_modifier": "o"}}},
    ),
    "CreateTextEncoding": (b"IIII", "", {"retval": {"already_cfretained": True}}),
    "TECCountDirectTextEncodingConversions": (
        b"i^Q",
        "",
        {"arguments": {0: {"type_modifier": "o"}}},
    ),
    "TECGetTextEncodingInternetName": (
        b"iI[256C]",
        "",
        {"arguments": {1: {"type_modifier": "o"}}},
    ),
    "TECCountAvailableSniffers": (
        b"i^Q",
        "",
        {"arguments": {0: {"type_modifier": "o"}}},
    ),
    "ResolveDefaultTextEncoding": (b"II",),
    "LocaleRefFromLocaleString": (
        b"i^t^^{OpaqueLocaleRef=}",
        "",
        {
            "arguments": {
                0: {"c_array_delimited_by_null": True, "type_modifier": "n"},
                1: {"type_modifier": "o"},
            }
        },
    ),
    "GetTextEncodingBase": (b"II",),
    "TECGetAvailableSniffers": (
        b"i^IQ^Q",
        "",
        {
            "arguments": {
                0: {"c_array_length_in_arg": (1, 2), "type_modifier": "o"},
                2: {"type_modifier": "o"},
            }
        },
    ),
    "TECSetBasicOptions": (b"i^{OpaqueTECObjectRef=}I",),
    "CSBackupSetItemExcluded": (b"i^{__CFURL=}ZZ",),
    "CSDiskSpaceGetRecoveryEstimate": (b"Q^{__CFURL=}",),
    "LocaleOperationCountNames": (b"iI^Q",),
    "TECDisposeSniffer": (b"i^{OpaqueTECSnifferObjectRef=}",),
    "TECConvertTextToMultipleEncodings": (
        b"i^{OpaqueTECObjectRef=}^CQ^Q^CQ^Q^{TextEncodingRun=QI}Q^Q",
        "",
        {
            "arguments": {
                1: {"c_array_length_in_arg": 2, "type_modifier": "n"},
                3: {"type_modifier": "o"},
                4: {"c_array_length_in_arg": (5, 6), "type_modifier": "o"},
                6: {"type_modifier": "o"},
                7: {"c_array_length_in_arg": (8, 9), "type_modifier": "o"},
                9: {"type_modifier": "o"},
            }
        },
    ),
    "TECFlushText": (
        b"i^{OpaqueTECObjectRef=}^CQ^Q",
        "",
        {
            "arguments": {
                1: {"c_array_length_in_arg": (2, 3), "type_modifier": "o"},
                3: {"type_modifier": "o"},
            }
        },
    ),
    "UpgradeScriptInfoToTextEncoding": (
        b"isss^C^I",
        "",
        {"arguments": {3: {"type_modifier": "n"}, 4: {"type_modifier": "o"}}},
    ),
    "TECClearSnifferContextInfo": (b"i^{OpaqueTECSnifferObjectRef=}",),
    "UCGetUnicodeScalarValueForSurrogatePair": (b"ITT",),
    "UCIsSurrogateHighCharacter": (b"ZT",),
    "TECCountSubTextEncodings": (
        b"iI^Q",
        "",
        {"arguments": {1: {"type_modifier": "o"}}},
    ),
    "TECConvertText": (
        b"i^{OpaqueTECObjectRef=}^CQ^Q^CQ^Q",
        "",
        {
            "arguments": {
                1: {"c_array_length_in_arg": 2, "type_modifier": "n"},
                3: {"type_modifier": "o"},
                4: {"c_array_length_in_arg": (5, 6), "type_modifier": "o"},
                6: {"type_modifier": "o"},
            }
        },
    ),
    "TECGetDirectTextEncodingConversions": (
        b"i^{TECConversionInfo=IISS}Q^Q",
        "",
        {
            "arguments": {
                0: {"c_array_length_in_arg": (1, 2), "type_modifier": "o"},
                2: {"type_modifier": "o"},
            }
        },
    ),
    "GetTextEncodingName": (
        b"iIIsIQ^Q^s^I^t",
        "",
        {
            "arguments": {
                8: {"c_array_length_in_arg": (4, 5), "type_modifier": "o"},
                5: {"type_modifier": "o"},
                6: {"type_modifier": "o"},
                7: {"type_modifier": "o"},
            }
        },
    ),
    "RevertTextEncodingToScriptInfo": (
        b"iI^s^s[256C]",
        "",
        {
            "arguments": {
                1: {"type_modifier": "o"},
                2: {"type_modifier": "o"},
                3: {"type_modifier": "o"},
            }
        },
    ),
    "TECGetSubTextEncodings": (
        b"iI^IQ^Q",
        "",
        {
            "arguments": {
                1: {"c_array_length_in_arg": (2, 3), "type_modifier": "o"},
                3: {"type_modifier": "o"},
            }
        },
    ),
    "TECCopyTextEncodingInternetNameAndMIB": (
        b"iII^^{__CFString=}^i",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {"already_cfretained": True, "type_modifier": "o"},
                3: {"type_modifier": "o"},
            },
        },
    ),
    "TECGetAvailableTextEncodings": (
        b"i^IQ^Q",
        "",
        {
            "arguments": {
                0: {"c_array_length_in_arg": (1, 2), "type_modifier": "o"},
                2: {"type_modifier": "o"},
            }
        },
    ),
    "UCGetCharProperty": (
        b"i^TQi^I",
        "",
        {
            "arguments": {
                0: {"c_array_length_in_arg": 1, "type_modifier": "n"},
                3: {"type_modifier": "o"},
            }
        },
    ),
    "LocaleRefFromLangOrRegionCode": (
        b"iss^^{OpaqueLocaleRef=}",
        "",
        {"arguments": {2: {"type_modifier": "o"}}},
    ),
    "TECCreateConverterFromPath": (
        b"i^^{OpaqueTECObjectRef=}^IQ",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                0: {"type_modifier": "o"},
                1: {"c_array_length_in_arg": 2, "type_modifier": "n"},
            },
        },
    ),
    "TECCreateConverter": (
        b"i^^{OpaqueTECObjectRef=}II",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {0: {"type_modifier": "o"}},
        },
    ),
    "NearestMacTextEncodings": (
        b"iI^I^I",
        "",
        {"arguments": {1: {"type_modifier": "o"}, 2: {"type_modifier": "o"}}},
    ),
    "TECCountMailTextEncodings": (
        b"is^Q",
        "",
        {"arguments": {1: {"type_modifier": "o"}}},
    ),
    "TECCountAvailableTextEncodings": (
        b"i^Q",
        "",
        {"arguments": {0: {"type_modifier": "o"}}},
    ),
    "TECGetDestinationTextEncodings": (
        b"iI^IQ^Q",
        "",
        {
            "arguments": {
                1: {"c_array_length_in_arg": (2, 3), "type_modifier": "o"},
                3: {"type_modifier": "o"},
            }
        },
    ),
    "LocaleOperationGetName": (
        b"iI^{OpaqueLocaleRef=}Q^Q^t",
        "",
        {
            "arguments": {
                3: {"type_modifier": "o"},
                4: {"c_array_length_in_arg": (2, 3), "type_modifier": "o"},
            }
        },
    ),
    "TECFlushMultipleEncodings": (
        b"i^{OpaqueTECObjectRef=}^CQ^Q^{TextEncodingRun=QI}Q^Q",
        "",
        {
            "arguments": {
                1: {"c_array_length_in_arg": (2, 3), "type_modifier": "o"},
                3: {"type_modifier": "o"},
                4: {"c_array_length_in_arg": (5, 6), "type_modifier": "o"},
                6: {"type_modifier": "o"},
            }
        },
    ),
    "LocaleOperationGetIndName": (
        b"iIQQ^Q^t^^{OpaqueLocaleRef=}",
        "",
        {
            "arguments": {
                3: {"type_modifier": "o"},
                4: {"c_array_length_in_arg": (2, 3), "type_modifier": "o"},
                5: {"type_modifier": "o"},
            }
        },
    ),
    "TECCountDestinationTextEncodings": (
        b"iI^Q",
        "",
        {"arguments": {1: {"type_modifier": "o"}}},
    ),
    "GetScriptInfoFromTextEncoding": (
        b"iI^s^s",
        "",
        {"arguments": {1: {"type_modifier": "o"}, 2: {"type_modifier": "o"}}},
    ),
    "GetTextEncodingVariant": (b"II",),
    "TECDisposeConverter": (b"i^{OpaqueTECObjectRef=}",),
    "TECGetTextEncodingFromInternetName": (
        b"i^I^C",
        "",
        {"arguments": {0: {"type_modifier": "o"}, 1: {"type_modifier": "n"}}},
    ),
    "CSDiskSpaceCancelRecovery": (b"v^{__CFUUID=}",),
}
cftypes = [
    ("FSFileOperationRef", b"^{__FSFileOperation=}", None, None),
    ("FSFileSecurityRef", b"^{__FSFileSecurity=}", None, None),
]
misc.update(
    {
        "TECSnifferObjectRef": objc.createOpaquePointerType(
            "TECSnifferObjectRef", b"^{OpaqueTECSnifferObjectRef=}"
        ),
        "TECObjectRef": objc.createOpaquePointerType(
            "TECObjectRef", b"^{OpaqueTECObjectRef=}"
        ),
    }
)
expressions = {}

# END OF FILE



# This file is generated by objective.metadata
#
# Last update: Sun Feb 20 18:46:06 2022
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$$"""
enums = """$$"""
misc.update({})
misc.update({})
functions = {
    "DCSDictionaryGetTypeID": (
        b"l",
        "",
        {"comment": "Function not present in header files"},
    ),
    "DCSGetTermRangeInString": (b"{_CFRange=qq}^{__DCSDictionary=}^{__CFString=}q",),
    "DCSCopyTextDefinition": (
        b"^{__CFString=}^{__DCSDictionary=}^{__CFString=}{_CFRange=qq}",
        "",
        {"retval": {"already_retained": True, "already_cfretained": True}},
    ),
}
cftypes = [("DCSDictionaryRef", b"^{__DCSDictionary=}", "DCSDictionaryGetTypeID", None)]
expressions = {}

# END OF FILE



# This file is generated by objective.metadata
#
# Last update: Sun Feb 20 18:46:06 2022
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
misc.update(
    {
        "MDQueryBatchingParams": objc.createStructType(
            "CoreServices.Metadata.MDQueryBatchingParams",
            b"{_MDQueryBatchingParams=QQQQQQ}",
            [
                "first_max_num",
                "first_max_ms",
                "progress_max_num",
                "progress_max_ms",
                "update_max_num",
                "update_max_ms",
            ],
        )
    }
)
constants = """$kMDAttributeAllValues$kMDAttributeDisplayValues$kMDAttributeMultiValued$kMDAttributeName$kMDAttributeReadOnlyValues$kMDAttributeType$kMDExporterAvaliable$kMDItemAcquisitionMake$kMDItemAcquisitionModel$kMDItemAlbum$kMDItemAltitude$kMDItemAperture$kMDItemAppleLoopDescriptors$kMDItemAppleLoopsKeyFilterType$kMDItemAppleLoopsLoopMode$kMDItemAppleLoopsRootKey$kMDItemApplicationCategories$kMDItemAttributeChangeDate$kMDItemAudiences$kMDItemAudioBitRate$kMDItemAudioChannelCount$kMDItemAudioEncodingApplication$kMDItemAudioSampleRate$kMDItemAudioTrackNumber$kMDItemAuthorAddresses$kMDItemAuthorEmailAddresses$kMDItemAuthors$kMDItemBitsPerSample$kMDItemCFBundleIdentifier$kMDItemCameraOwner$kMDItemCity$kMDItemCodecs$kMDItemColorSpace$kMDItemComment$kMDItemComposer$kMDItemContactKeywords$kMDItemContentCreationDate$kMDItemContentModificationDate$kMDItemContentType$kMDItemContentTypeTree$kMDItemContributors$kMDItemCopyright$kMDItemCountry$kMDItemCoverage$kMDItemCreator$kMDItemDateAdded$kMDItemDeliveryType$kMDItemDescription$kMDItemDirector$kMDItemDisplayName$kMDItemDownloadedDate$kMDItemDueDate$kMDItemDurationSeconds$kMDItemEXIFGPSVersion$kMDItemEXIFVersion$kMDItemEditors$kMDItemEmailAddresses$kMDItemEncodingApplications$kMDItemExecutableArchitectures$kMDItemExecutablePlatform$kMDItemExposureMode$kMDItemExposureProgram$kMDItemExposureTimeSeconds$kMDItemExposureTimeString$kMDItemFNumber$kMDItemFSContentChangeDate$kMDItemFSCreationDate$kMDItemFSExists$kMDItemFSHasCustomIcon$kMDItemFSInvisible$kMDItemFSIsExtensionHidden$kMDItemFSIsReadable$kMDItemFSIsStationery$kMDItemFSIsWriteable$kMDItemFSLabel$kMDItemFSName$kMDItemFSNodeCount$kMDItemFSOwnerGroupID$kMDItemFSOwnerUserID$kMDItemFSSize$kMDItemFinderComment$kMDItemFlashOnOff$kMDItemFocalLength$kMDItemFocalLength35mm$kMDItemFonts$kMDItemGPSAreaInformation$kMDItemGPSDOP$kMDItemGPSDateStamp$kMDItemGPSDestBearing$kMDItemGPSDestDistance$kMDItemGPSDestLatitude$kMDItemGPSDestLongitude$kMDItemGPSDifferental$kMDItemGPSMapDatum$kMDItemGPSMeasureMode$kMDItemGPSProcessingMethod$kMDItemGPSStatus$kMDItemGPSTrack$kMDItemGenre$kMDItemHTMLContent$kMDItemHasAlphaChannel$kMDItemHeadline$kMDItemISOSpeed$kMDItemIdentifier$kMDItemImageDirection$kMDItemInformation$kMDItemInstantMessageAddresses$kMDItemInstructions$kMDItemIsApplicationManaged$kMDItemIsGeneralMIDISequence$kMDItemIsLikelyJunk$kMDItemKeySignature$kMDItemKeywords$kMDItemKind$kMDItemLabelID$kMDItemLabelIcon$kMDItemLabelKind$kMDItemLabelUUID$kMDItemLanguages$kMDItemLastUsedDate$kMDItemLatitude$kMDItemLayerNames$kMDItemLensModel$kMDItemLongitude$kMDItemLyricist$kMDItemMaxAperture$kMDItemMediaTypes$kMDItemMeteringMode$kMDItemMusicalGenre$kMDItemMusicalInstrumentCategory$kMDItemMusicalInstrumentName$kMDItemNamedLocation$kMDItemNumberOfPages$kMDItemOrganizations$kMDItemOrientation$kMDItemOriginalFormat$kMDItemOriginalSource$kMDItemPageHeight$kMDItemPageWidth$kMDItemParticipants$kMDItemPath$kMDItemPerformers$kMDItemPhoneNumbers$kMDItemPixelCount$kMDItemPixelHeight$kMDItemPixelWidth$kMDItemProducer$kMDItemProfileName$kMDItemProjects$kMDItemPublishers$kMDItemRecipientAddresses$kMDItemRecipientEmailAddresses$kMDItemRecipients$kMDItemRecordingDate$kMDItemRecordingYear$kMDItemRedEyeOnOff$kMDItemResolutionHeightDPI$kMDItemResolutionWidthDPI$kMDItemRights$kMDItemSecurityMethod$kMDItemSpeed$kMDItemStarRating$kMDItemStateOrProvince$kMDItemStreamable$kMDItemSubject$kMDItemSupportFileType$kMDItemTempo$kMDItemTextContent$kMDItemTheme$kMDItemTimeSignature$kMDItemTimestamp$kMDItemTitle$kMDItemTotalBitRate$kMDItemURL$kMDItemVersion$kMDItemVideoBitRate$kMDItemWhereFroms$kMDItemWhiteBalance$kMDLabelAddedNotification$kMDLabelBundleURL$kMDLabelChangedNotification$kMDLabelContentChangeDate$kMDLabelDisplayName$kMDLabelIconData$kMDLabelIconUUID$kMDLabelIsMutuallyExclusiveSetMember$kMDLabelKind$kMDLabelKindIsMutuallyExclusiveSetKey$kMDLabelKindVisibilityKey$kMDLabelRemovedNotification$kMDLabelSetsFinderColor$kMDLabelUUID$kMDLabelVisibility$kMDPrivateVisibility$kMDPublicVisibility$kMDQueryDidFinishNotification$kMDQueryDidUpdateNotification$kMDQueryProgressNotification$kMDQueryResultContentRelevance$kMDQueryScopeAllIndexed$kMDQueryScopeComputer$kMDQueryScopeComputerIndexed$kMDQueryScopeHome$kMDQueryScopeNetwork$kMDQueryScopeNetworkIndexed$kMDQueryUpdateAddedItems$kMDQueryUpdateChangedItems$kMDQueryUpdateRemovedItems$"""
enums = """$kMDLabelLocalDomain@1$kMDLabelUserDomain@0$kMDQueryAllowFSTranslation@8$kMDQueryReverseSortOrderFlag@1$kMDQuerySynchronous@1$kMDQueryWantsUpdates@4$"""
misc.update({})
misc.update({})
functions = {
    "MDQueryCreate": (
        b"^{__MDQuery=}^{__CFAllocator=}^{__CFString=}^{__CFArray=}^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDItemCopyAttributes": (
        b"^{__CFDictionary=}^{__MDItem=}^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDLabelCreate": (
        b"^{__MDLabel=}^{__CFAllocator=}^{__CFString=}^{__CFString=}I",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDLabelGetTypeID": (b"Q",),
    "MDQueryGetAttributeValueOfResultAtIndex": (b"@^{__MDQuery=}^{__CFString=}q",),
    "MDQueryCreateForItems": (
        b"^{__MDQuery=}^{__CFAllocator=}^{__CFString=}^{__CFArray=}^{__CFArray=}^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDQueryCopyValueListAttributes": (
        b"^{__CFArray=}^{__MDQuery=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDLabelCopyAttributeName": (
        b"^{__CFString=}^{__MDLabel=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDCopyLabelsWithKind": (
        b"^{__CFArray=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDQueryGetIndexOfResult": (b"q^{__MDQuery=}@",),
    "MDLabelDelete": (b"Z^{__MDLabel=}",),
    "MDSchemaCopyDisplayNameForAttribute": (
        b"^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDItemCopyAttribute": (
        b"@^{__MDItem=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDQueryDisableUpdates": (b"v^{__MDQuery=}",),
    "MDItemCopyAttributeList": (
        b"^{__CFDictionary=}^{__MDItem=}",
        "",
        {"retval": {"already_cfretained": True}, "variadic": True},
    ),
    "MDItemCreate": (
        b"^{__MDItem=}^{__CFAllocator=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDQueryGetSortOptionFlagsForAttribute": (b"I^{__MDQuery=}^{__CFString=}",),
    "MDQueryGetBatchingParameters": (b"{_MDQueryBatchingParams=QQQQQQ}^{__MDQuery=}",),
    "MDCopyLabelWithUUID": (
        b"^{__MDLabel=}^{__CFUUID=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDQueryEnableUpdates": (b"v^{__MDQuery=}",),
    "MDQuerySetMaxCount": (b"v^{__MDQuery=}q",),
    "MDQueryCopyValuesOfAttribute": (
        b"^{__CFArray=}^{__MDQuery=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDItemsCreateWithURLs": (
        b"^{__CFArray=}^{__CFAllocator=}^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDQuerySetCreateValueFunction": (
        b"v^{__MDQuery=}^?^v^{_CFArrayCallBacks=q^?^?^?^?}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"^v"},
                        "arguments": {
                            0: {"type": b"^{__MDQuery=}"},
                            1: {"type": b"^{__CFString=}"},
                            2: {"type": b"@"},
                            3: {"type": b"^v"},
                        },
                    }
                }
            },
        },
    ),
    "MDSchemaCopyDisplayDescriptionForAttribute": (
        b"^{__CFString=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDCopyLabelsMatchingExpression": (
        b"^{__CFArray=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDQuerySetSortOrder": (b"Z^{__MDQuery=}^{__CFArray=}",),
    "MDQuerySetSortComparator": (
        b"v^{__MDQuery=}^?^v",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": sel32or64(b"i", b"q")},
                        "arguments": {
                            0: {
                                "type": b"^@",
                                "type_modifier": "n",
                                "c_array_of_variable_length": True,
                            },
                            1: {
                                "type": b"^@",
                                "type_modifier": "n",
                                "c_array_of_variable_length": True,
                            },
                            2: {"type": b"^v"},
                        },
                    }
                }
            }
        },
    ),
    "MDSchemaCopyAllAttributes": (
        b"^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDQueryStop": (b"v^{__MDQuery=}",),
    "MDQuerySetSearchScope": (b"v^{__MDQuery=}^{__CFArray=}I",),
    "MDQueryIsGatheringComplete": (b"Z^{__MDQuery=}",),
    "MDQuerySetCreateResultFunction": (
        b"v^{__MDQuery=}^?^v^{_CFArrayCallBacks=q^?^?^?^?}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": b"^v"},
                        "arguments": {
                            0: {"type": b"^{__MDQuery=}"},
                            1: {"type": b"^{__MDItem=}"},
                            2: {"type": b"^v"},
                        },
                    }
                }
            },
        },
    ),
    "MDItemCopyLabels": (
        b"^{__CFArray=}^{__MDItem=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDSchemaCopyAttributesForContentType": (
        b"^{__CFDictionary=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDItemSetLabel": (b"Z^{__MDItem=}^{__MDLabel=}",),
    "MDQueryExecute": (b"Z^{__MDQuery=}Q",),
    "MDQuerySetDispatchQueue": (b"v^{__MDQuery=}@",),
    "MDLabelSetAttributes": (b"Z^{__MDLabel=}^{__CFDictionary=}",),
    "MDItemGetTypeID": (b"Q",),
    "MDQueryCopyQueryString": (
        b"^{__CFString=}^{__MDQuery=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDQueryCopySortingAttributes": (
        b"^{__CFArray=}^{__MDQuery=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDQuerySetSortOptionFlagsForAttribute": (b"Z^{__MDQuery=}^{__CFString=}I",),
    "MDQuerySetBatchingParameters": (b"v^{__MDQuery=}{_MDQueryBatchingParams=QQQQQQ}",),
    "MDQueryCreateSubset": (
        b"^{__MDQuery=}^{__CFAllocator=}^{__MDQuery=}^{__CFString=}^{__CFArray=}^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDQueryGetTypeID": (b"Q",),
    "MDItemCreateWithURL": (
        b"^{__MDItem=}^{__CFAllocator=}^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDQuerySetSortComparatorBlock": (
        b"v^{__MDQuery=}@?",
        "",
        {
            "arguments": {
                1: {
                    "callable": {
                        "retval": {"type": sel32or64(b"i", b"q")},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {
                                "type": "^@",
                                "type_modifier": "n",
                                "c_array_of_variable_length": True,
                            },
                            2: {
                                "type": "^@",
                                "type_modifier": "n",
                                "c_array_of_variable_length": True,
                            },
                        },
                    },
                    "block": {
                        "retval": {"type": b"q"},
                        "arguments": {0: {"type": b"^@"}, 1: {"type": b"^@"}},
                    },
                }
            }
        },
    ),
    "MDItemCopyAttributeNames": (
        b"^{__CFArray=}^{__MDItem=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDQueryGetCountOfResultsWithAttributeValue": (b"q^{__MDQuery=}^{__CFString=}@",),
    "MDItemsCopyAttributes": (
        b"^{__CFArray=}^{__CFArray=}^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDQueryGetResultCount": (b"q^{__MDQuery=}",),
    "MDCopyLabelKinds": (
        b"^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDItemRemoveLabel": (b"Z^{__MDItem=}^{__MDLabel=}",),
    "MDQueryGetResultAtIndex": (b"@^{__MDQuery=}q",),
    "MDSchemaCopyMetaAttributesForAttribute": (
        b"^{__CFDictionary=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MDLabelCopyAttribute": (
        b"@^{__MDLabel=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
}
aliases = {
    "MD_AVAIL": "AVAILABLE_MAC_OS_X_VERSION_10_4_AND_LATER",
    "MD_AVAIL_LEOPARD": "AVAILABLE_MAC_OS_X_VERSION_10_5_AND_LATER",
}
cftypes = [
    ("MDItemRef", b"^{__MDItem=}", None, None),
    ("MDLabelRef", b"^{__MDLabel=}", None, None),
    ("MDQueryRef", b"^{__MDQuery=}", None, None),
]
expressions = {}

# END OF FILE



"""
Python mapping for the SearchKit framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""
import sys

import CoreFoundation
import objc
from CoreServices.SearchKit import _metadata

mod = objc.ObjCLazyModule(
    "SearchKit",
    "com.apple.SearchKit",
    objc.pathForFramework(
        "/System/Library/Frameworks/CoreServices.framework/Frameworks/SearchKit.framework"
    ),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (CoreFoundation,),
)


del sys.modules["CoreServices.SearchKit._metadata"]


# SKIndexGetTypeID is documented, but not actually exported by Leopard. Try to
# emulate the missing functionality.
#
# See also radar:6525606.
#
# UPDATE 20151123: The workaround is still necessary on OSX 10.11
def workaround():
    from Foundation import NSMutableData, NSAutoreleasePool

    pool = NSAutoreleasePool.alloc().init()
    try:
        rI = mod.SKIndexCreateWithMutableData(
            NSMutableData.data(), None, mod.kSKIndexInverted, None
        )

        indexID = mod.CFGetTypeID(rI)

        r = mod.SKIndexDocumentIteratorCreate(rI, None)
        iterID = mod.CFGetTypeID(r)
        del r

        r = mod.SKSearchGroupCreate([rI])
        groupID = mod.CFGetTypeID(r)

        r = mod.SKSearchResultsCreateWithQuery(
            r, ".*", mod.kSKSearchRanked, 1, None, None
        )
        resultID = mod.CFGetTypeID(r)

        if mod.SKSearchGetTypeID() == 0:
            # Type doesn't get registered unless you try to use it.
            # That's no good for PyObjC, therefore forcefully create
            # a SKSearch object
            mod.SKSearchCreate(rI, "q", 0)
            searchref = objc.registerCFSignature(
                "SKSearchRef", b"^{__SKSearch=}", mod.SKSearchGetTypeID()
            )
        else:
            searchref = mod.SKSearchRef

        del r
        del rI

        r = mod.SKSummaryCreateWithString("foo")
        summaryID = mod.CFGetTypeID(r)
        del r

    finally:
        del pool

    def SKIndexGetTypeID():
        return indexID

    def SKIndexDocumentIteratorGetTypeID():
        return iterID

    def SKSearchGroupGetTypeID():
        return groupID

    def SKSearchResultsGetTypeID():
        return resultID

    def SKSummaryGetTypeID():
        return summaryID

    indexType = objc.registerCFSignature("SKIndexRef", b"^{__SKIndex=}", indexID)
    iterType = objc.registerCFSignature(
        "SKIndexDocumentIteratorRef", b"^{__SKIndexDocumentIterator=}", iterID
    )
    groupType = objc.registerCFSignature(
        "SKSearchGroupRef", b"^{__SKSearchGroup=}", groupID
    )
    resultType = objc.registerCFSignature(
        "SKSearchResultsRef", b"^{__SKSearchResults=}", resultID
    )
    summaryType = objc.registerCFSignature(
        "SKSummaryRef", b"^{__SKSummary=}", summaryID
    )

    # For some reason SKDocumentGetTypeID doesn't return the right value
    # when the framework loader calls it the first time around,
    # by this time the framework is fully initialized and we get
    # the correct result.
    SKDocumentRef = objc.registerCFSignature(
        "SKDocumentRef", b"@", mod.SKDocumentGetTypeID()
    )

    return (
        SKIndexGetTypeID,
        indexType,
        SKIndexDocumentIteratorGetTypeID,
        iterType,
        SKSearchGroupGetTypeID,
        groupType,
        SKSearchResultsGetTypeID,
        resultType,
        SKSummaryGetTypeID,
        summaryType,
        iterType,
        SKDocumentRef,
        searchref,
    )


(
    mod.SKIndexGetTypeID,
    mod.SKIndexRef,
    mod.SKIndexDocumentIteratorGetTypeID,
    mod.SKIndexDocumentRef,
    mod.SKSearchGroupGetTypeID,
    mod.SKSearchGroupRef,
    mod.SKSearchResultsGetTypeID,
    mod.SKSearchResultsRef,
    mod.SKSummaryGetTypeID,
    mod.SKSummaryRef,
    mod.SKIndexDocumentIteratorRef,
    mod.SKDocumentRef,
    mod.SKSearchRef,
) = workaround()

del workaround

sys.modules["CoreServices.SearchKit"] = mod



"""
Python mapping for the CoreServices framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.

Note that PyObjC only wrappers the non-deprecated parts of the CoreServices
framework.
"""
import sys

import FSEvents
import objc
from CoreServices import (
    CarbonCore,
    DictionaryServices,
    LaunchServices,
    Metadata,
    SearchKit,
)

sys.modules["CoreServices"] = mod = objc.ObjCLazyModule(
    "CoreServices",
    "com.apple.CoreServices",
    objc.pathForFramework("/System/Library/Frameworks/CoreServices.framework"),
    {},
    None,
    {
        "__doc__": __doc__,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
        "objc": objc,
    },
    (FSEvents, DictionaryServices, LaunchServices, SearchKit, Metadata, CarbonCore),
)



# This file is generated by objective.metadata
#
# Last update: Sun Feb 20 18:46:07 2022
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$kSKEndTermChars$kSKLanguageTypes$kSKMaximumTerms$kSKMinTermLength$kSKProximityIndexing$kSKStartTermChars$kSKStopWords$kSKSubstitutions$kSKTermChars$"""
enums = """$kSKDocumentStateAddPending@2$kSKDocumentStateDeletePending@3$kSKDocumentStateIndexed@1$kSKDocumentStateNotIndexed@0$kSKIndexInverted@1$kSKIndexInvertedVector@3$kSKIndexUnknown@0$kSKIndexVector@2$kSKSearchBooleanRanked@1$kSKSearchOptionDefault@0$kSKSearchOptionFindSimilar@4$kSKSearchOptionNoRelevanceScores@1$kSKSearchOptionSpaceMeansOR@2$kSKSearchPrefixRanked@3$kSKSearchRanked@0$kSKSearchRequiredRanked@2$"""
misc.update(
    {
        "SKDocumentIndexState": NewType("SKDocumentIndexState", int),
        "SKIndexType": NewType("SKIndexType", int),
        "SKSearchType": NewType("SKSearchType", int),
    }
)
misc.update({})
functions = {
    "SKIndexGetMaximumTermID": (b"q^{__SKIndex=}",),
    "SKDocumentGetName": (b"^{__CFString=}@",),
    "SKIndexRemoveDocument": (b"Z^{__SKIndex=}@",),
    "SKIndexCopyTermIDArrayForDocumentID": (
        b"^{__CFArray=}^{__SKIndex=}q",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SKSearchGetTypeID": (b"Q",),
    "SKIndexDocumentIteratorCreate": (
        b"^{__SKIndexDocumentIterator=}^{__SKIndex=}@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SKDocumentGetTypeID": (b"Q",),
    "SKSummaryGetParagraphSummaryInfo": (
        b"q^{__SKSummary=}q^q^q",
        "",
        {"arguments": {2: {"type_modifier": "o"}, 3: {"type_modifier": "o"}}},
    ),
    "SKSummaryGetParagraphCount": (b"q^{__SKSummary=}",),
    "SKIndexGetMaximumDocumentID": (b"q^{__SKIndex=}",),
    "SKSearchGroupCreate": (
        b"^{__SKSearchGroup=}^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SKIndexFlush": (b"Z^{__SKIndex=}",),
    "SKIndexCreateWithURL": (
        b"^{__SKIndex=}^{__CFURL=}^{__CFString=}I^{__CFDictionary=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SKSummaryGetSentenceCount": (b"q^{__SKSummary=}",),
    "SKIndexGetMaximumBytesBeforeFlush": (b"q^{__SKIndex=}",),
    "SKIndexCopyDocumentIDArrayForTermID": (
        b"^{__CFArray=}^{__SKIndex=}q",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SKSearchResultsCreateWithDocuments": (
        b"^{__SKSearchResults=}^{__SKSearchGroup=}^{__CFArray=}q^v^?",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"Z"},
                        "arguments": {
                            0: {"type": b"^{__SKIndex=}"},
                            1: {"type": b"@"},
                            2: {"type": b"^v"},
                        },
                    }
                }
            },
        },
    ),
    "SKSummaryCopyParagraphAtIndex": (
        b"^{__CFString=}^{__SKSummary=}q",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SKIndexGetDocumentID": (b"q^{__SKIndex=}@",),
    "SKIndexOpenWithURL": (b"^{__SKIndex=}^{__CFURL=}^{__CFString=}Z",),
    "SKIndexCreateWithMutableData": (
        b"^{__SKIndex=}^{__CFData=}^{__CFString=}I^{__CFDictionary=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SKIndexCopyDocumentURLsForDocumentIDs": (
        b"v^{__SKIndex=}q^q^^{__CFURL=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {"c_array_length_in_arg": 1, "type_modifier": "n"},
                3: {
                    "already_cfretained": True,
                    "c_array_length_in_arg": 1,
                    "type_modifier": "o",
                },
            },
        },
    ),
    "SKSearchResultsCreateWithQuery": (
        b"^{__SKSearchResults=}^{__SKSearchGroup=}^{__CFString=}Iq^v^?",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"Z"},
                        "arguments": {
                            0: {"type": b"^{__SKIndex=}"},
                            1: {"type": b"@"},
                            2: {"type": b"^v"},
                        },
                    }
                }
            },
        },
    ),
    "SKIndexCompact": (b"Z^{__SKIndex=}",),
    "SKSearchGroupGetTypeID": (b"Q",),
    "SKSummaryCopySentenceAtIndex": (
        b"^{__CFString=}^{__SKSummary=}q",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SKSearchGroupCopyIndexes": (
        b"^{__CFArray=}^{__SKSearchGroup=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SKLoadDefaultExtractorPlugIns": (b"v",),
    "SKIndexMoveDocument": (b"Z^{__SKIndex=}@@",),
    "SKIndexOpenWithData": (b"^{__SKIndex=}^{__CFData=}^{__CFString=}",),
    "SKIndexCopyDocumentProperties": (
        b"^{__CFDictionary=}^{__SKIndex=}@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SKIndexCopyDocumentRefsForDocumentIDs": (
        b"v^{__SKIndex=}q^q^@",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {"c_array_length_in_arg": 1, "type_modifier": "n"},
                3: {"c_array_length_in_arg": 1, "type_modifier": "o"},
            },
        },
    ),
    "SKIndexOpenWithMutableData": (b"^{__SKIndex=}^{__CFData=}^{__CFString=}",),
    "SKSearchResultsCopyMatchingTerms": (
        b"^{__CFArray=}^{__SKSearchResults=}q",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SKDocumentGetParent": (b"@@",),
    "SKSearchResultsGetTypeID": (b"Q",),
    "SKSummaryCreateWithString": (
        b"^{__SKSummary=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SKIndexGetDocumentTermCount": (b"q^{__SKIndex=}q",),
    "SKIndexSetDocumentProperties": (b"v^{__SKIndex=}@^{__CFDictionary=}",),
    "SKSummaryGetSentenceSummaryInfo": (
        b"q^{__SKSummary=}q^q^q^q",
        "",
        {
            "arguments": {
                2: {"type_modifier": "o"},
                3: {"type_modifier": "o"},
                4: {"type_modifier": "o"},
            }
        },
    ),
    "SKDocumentCreate": (
        b"@^{__CFString=}@^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SKDocumentCreateWithURL": (
        b"@^{__CFURL=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SKIndexClose": (b"v^{__SKIndex=}",),
    "SKIndexGetDocumentTermFrequency": (b"q^{__SKIndex=}qq",),
    "SKIndexDocumentIteratorCopyNext": (
        b"@^{__SKIndexDocumentIterator=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SKIndexRenameDocument": (b"Z^{__SKIndex=}@^{__CFString=}",),
    "SKSummaryGetTypeID": (b"Q",),
    "SKDocumentGetSchemeName": (b"^{__CFString=}@",),
    "SKDocumentCopyURL": (
        b"^{__CFURL=}@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SKIndexGetTypeID": (b"Q",),
    "SKSearchCancel": (b"v^{__SKSearch=}",),
    "SKIndexGetDocumentCount": (b"q^{__SKIndex=}",),
    "SKSummaryCopySentenceSummaryString": (
        b"^{__CFString=}^{__SKSummary=}q",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SKIndexGetTermDocumentCount": (b"q^{__SKIndex=}q",),
    "SKIndexGetTermIDForTermString": (b"q^{__SKIndex=}^{__CFString=}",),
    "SKSummaryCopyParagraphSummaryString": (
        b"^{__CFString=}^{__SKSummary=}q",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SKIndexGetDocumentState": (b"I^{__SKIndex=}@",),
    "SKSearchCreate": (
        b"^{__SKSearch=}^{__SKIndex=}^{__CFString=}I",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SKIndexAddDocumentWithText": (b"Z^{__SKIndex=}@^{__CFString=}Z",),
    "SKIndexAddDocument": (b"Z^{__SKIndex=}@^{__CFString=}Z",),
    "SKIndexSetMaximumBytesBeforeFlush": (b"v^{__SKIndex=}q",),
    "SKSearchFindMatches": (
        b"Z^{__SKSearch=}q^q^fd^q",
        "",
        {
            "arguments": {
                2: {"c_array_length_in_arg": (1, 5), "type_modifier": "o"},
                3: {"c_array_length_in_arg": (1, 5), "type_modifier": "o"},
                5: {"type_modifier": "o"},
            }
        },
    ),
    "SKIndexCopyTermStringForTermID": (
        b"^{__CFString=}^{__SKIndex=}q",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SKIndexGetAnalysisProperties": (b"^{__CFDictionary=}^{__SKIndex=}",),
    "SKSearchResultsGetCount": (b"q^{__SKSearchResults=}",),
    "SKSearchResultsGetInfoInRange": (
        b"q^{__SKSearchResults=}{_CFRange=qq}^@^^{__SKIndex=}^f",
        "",
        {
            "arguments": {
                2: {
                    "c_array_length_in_arg": 1,
                    "c_array_length_in_result": True,
                    "type_modifier": "o",
                },
                3: {
                    "c_array_length_in_arg": 1,
                    "c_array_length_in_result": True,
                    "type_modifier": "o",
                },
                4: {
                    "c_array_length_in_arg": 1,
                    "c_array_length_in_result": True,
                    "type_modifier": "o",
                },
            }
        },
    ),
    "SKIndexCopyDocumentForDocumentID": (
        b"@^{__SKIndex=}q",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "SKIndexCopyInfoForDocumentIDs": (
        b"v^{__SKIndex=}q^q^^{__CFString=}^q",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                2: {"c_array_length_in_arg": 1, "type_modifier": "n"},
                3: {
                    "already_cfretained": True,
                    "c_array_length_in_arg": 1,
                    "type_modifier": "o",
                },
                4: {"c_array_length_in_arg": 1, "type_modifier": "o"},
            },
        },
    ),
    "SKIndexGetIndexType": (b"I^{__SKIndex=}",),
    "SKIndexDocumentIteratorGetTypeID": (b"Q",),
}
cftypes = [
    (
        "SKIndexDocumentIteratorRef",
        b"^{__SKIndexDocumentIterator=}",
        "SKIndexDocumentIteratorGetTypeID",
        None,
    ),
    ("SKIndexRef", b"^{__SKIndex=}", "SKIndexGetTypeID", None),
    ("SKSearchGroupRef", b"^{__SKSearchGroup=}", "SKSearchGroupGetTypeID", None),
    ("SKSearchRef", b"^{__SKSearch=}", "SKSearchGetTypeID", None),
    ("SKSearchResultsRef", b"^{__SKSearchResults=}", "SKSearchResultsGetTypeID", None),
    ("SKSummaryRef", b"^{__SKSummary=}", "SKSummaryGetTypeID", None),
    ("SKDocumentRef", b"@", "SKDocumentGetTypeID", None),
]
expressions = {}

# END OF FILE
